<?php 
/* 
 ----------------------------------------------------------------------
 GLPI - Gestionnaire Libre de Parc Informatique
 Copyright (C) 2003-2010 by the INDEPNET Development Team.
 
 http://indepnet.net/   http://glpi-project.org
 ----------------------------------------------------------------------

 LICENSE

 This file is part of GLPI.

 GLPI is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.

 GLPI is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with GLPI; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ------------------------------------------------------------------------
 */
//tr_TR

$LANG=array();


$LANG['backup'][0]="SQL'e Yedekle"; 
$LANG['backup'][1]="XML'e Yedekle"; 
$LANG['backup'][11]="Boyut"; 
$LANG['backup'][13]="Görüntüle/İndir"; 
$LANG['backup'][16]="Replace the current database with the backup file:"; 
$LANG['backup'][17]="Delete this file"; 
$LANG['backup'][18]="Backup the database"; 
$LANG['backup'][19]="Şimdi"; 
$LANG['backup'][21]="Dosya zaten mevcut"; 
$LANG['backup'][22]="Bulunamayan byte"; 
$LANG['backup'][23]="Mysql hatasının başlangıcı :"; 
$LANG['backup'][24]="Otomotik yönlendirme başlıyor, iptal için tıklayınız"; 

$LANG['bookmark'][1]="Yer imi"; 
$LANG['bookmark'][2]="Partial load of the bookmark."; 
$LANG['bookmark'][3]="Henüz yerimini kaydetmediniz"; 
$LANG['bookmark'][4]="Yeni yerimi"; 
$LANG['bookmark'][5]="Genel yerimleri"; 
$LANG['bookmark'][6]="Varsayılan olarak uygula"; 

$LANG['buttons'][0]="Ara"; 
$LANG['buttons'][2]="Gönder"; 
$LANG['buttons'][3]="Associate"; 
$LANG['buttons'][4]="Kur"; 
$LANG['buttons'][5]="Kaldır"; 
$LANG['buttons'][6]="Sil"; 
$LANG['buttons'][7]="Güncelle"; 
$LANG['buttons'][8]="Ekle"; 
$LANG['buttons'][9]="Bağla"; 
$LANG['buttons'][10]="Bağlantıyı kaldır"; 
$LANG['buttons'][11]="Sonraki"; 
$LANG['buttons'][12]="Önceki"; 
$LANG['buttons'][13]="Geri"; 
$LANG['buttons'][14]="Güncelle"; 
$LANG['buttons'][15]="Planla"; 
$LANG['buttons'][16]="Boş"; 
$LANG['buttons'][17]="Seçimi tersine çevir"; 
$LANG['buttons'][18]="Hepsini işaretle"; 
$LANG['buttons'][19]="Tümünden işareti kaldır"; 
$LANG['buttons'][20]="Taşı"; 
$LANG['buttons'][21]="Geri yükle"; 
$LANG['buttons'][22]="Temizle"; 
$LANG['buttons'][23]="Göster"; 
$LANG['buttons'][24]="Yukarı çık"; 
$LANG['buttons'][25]="Aşağıya in"; 
$LANG['buttons'][27]="Current page in PDF"; 
$LANG['buttons'][28]="Current page in SLK"; 
$LANG['buttons'][29]="All pages in PDF"; 
$LANG['buttons'][30]="All pages in SLK"; 
$LANG['buttons'][31]="Dışarı ver"; 
$LANG['buttons'][32]="Son"; 
$LANG['buttons'][33]="Başla"; 
$LANG['buttons'][34]="İptal"; 
$LANG['buttons'][37]="Ekle"; 
$LANG['buttons'][38]="Kilidi kaldır"; 
$LANG['buttons'][39]="Değiştir"; 
$LANG['buttons'][40]="Tümünü göster"; 
$LANG['buttons'][41]="Etkinleştir"; 
$LANG['buttons'][42]="Pasifleştir"; 
$LANG['buttons'][43]="Araştır"; 
$LANG['buttons'][44]="Current page in CSV"; 
$LANG['buttons'][45]="All pages in CSV"; 
$LANG['buttons'][46]="Önce"; 
$LANG['buttons'][47]="Sonra"; 
$LANG['buttons'][48]="Aktar"; 
$LANG['buttons'][49]="Koru"; 
$LANG['buttons'][50]="Test"; 
$LANG['buttons'][51]="Kaydet"; 
$LANG['buttons'][52]="Yükle"; 
$LANG['buttons'][53]="Temizle"; 
$LANG['buttons'][55]="İlk"; 
$LANG['buttons'][56]="Son"; 
$LANG['buttons'][57]="Execute"; 
$LANG['buttons'][58]="Update"; 
$LANG['buttons'][59]="Dissociate"; 

$LANG['calendar'][0]="YYYY-MM-DD"; 
$LANG['calendar'][1]="DD-MM-YYYY"; 
$LANG['calendar'][2]="MM-DD-YYYY"; 

$LANG['calendarD'][0]="Paz"; 
$LANG['calendarD'][1]="Pzt"; 
$LANG['calendarD'][2]="Sal"; 
$LANG['calendarD'][3]="Çar"; 
$LANG['calendarD'][4]="Per"; 
$LANG['calendarD'][5]="Cum"; 
$LANG['calendarD'][6]="Cts"; 

$LANG['calendarDay'][0]="Pazar"; 
$LANG['calendarDay'][1]="Pazartesi"; 
$LANG['calendarDay'][2]="Salı"; 
$LANG['calendarDay'][3]="Çarşamba"; 
$LANG['calendarDay'][4]="Perşembe"; 
$LANG['calendarDay'][5]="Cuma"; 
$LANG['calendarDay'][6]="Cumartesi"; 

$LANG['calendarM'][0]="Ocak"; 
$LANG['calendarM'][1]="Şubat"; 
$LANG['calendarM'][2]="Mart"; 
$LANG['calendarM'][3]="Nisan"; 
$LANG['calendarM'][4]="Mayıs"; 
$LANG['calendarM'][5]="Haziran"; 
$LANG['calendarM'][6]="Temmuz"; 
$LANG['calendarM'][7]="Ağustos"; 
$LANG['calendarM'][8]="Eylül"; 
$LANG['calendarM'][9]="Ekim"; 
$LANG['calendarM'][10]="Kasım"; 
$LANG['calendarM'][11]="Aralık"; 

$LANG['cartridges'][0]="Kartuş"; 
$LANG['cartridges'][7]="Kartul bulunamadı"; 
$LANG['cartridges'][9]="Kartuş yok"; 
$LANG['cartridges'][10]="Toner"; 
$LANG['cartridges'][11]="Ink-Jet"; 
$LANG['cartridges'][12]="Kartuş tipi"; 
$LANG['cartridges'][13]="Yeni"; 
$LANG['cartridges'][14]="Kullanılmış"; 
$LANG['cartridges'][15]="Worn"; 
$LANG['cartridges'][16]="Kartuş(lar)"; 
$LANG['cartridges'][20]="Yeni"; 
$LANG['cartridges'][21]="Kullanılmış"; 
$LANG['cartridges'][22]="Worn"; 
$LANG['cartridges'][24]="Tarih ekle"; 
$LANG['cartridges'][27]="Açık"; 
$LANG['cartridges'][29]="Ömrünün sonu"; 
$LANG['cartridges'][32]="Uyumlu yazıcı modelleri"; 
$LANG['cartridges'][33]="Kullanılmış kartuşlar"; 
$LANG['cartridges'][34]="Boş kartuş yok"; 
$LANG['cartridges'][35]="Kullanılmış kartuşlar"; 
$LANG['cartridges'][37]="Ribbon"; 
$LANG['cartridges'][39]="Yazıcı sayacı"; 
$LANG['cartridges'][40]="Stoktaki ortalam süre"; 
$LANG['cartridges'][41]="Kullanımdaki ortalama süre"; 
$LANG['cartridges'][42]="Ortalama basılmış sayfa sayısı"; 

$LANG['central'][2]="Son"; 
$LANG['central'][4]="Etkinlik yok"; 
$LANG['central'][5]="Ana sayfa"; 
$LANG['central'][6]="Çıkış"; 
$LANG['central'][7]="Yardım"; 
$LANG['central'][8]="Ekler"; 
$LANG['central'][9]="İşlemdeki çağrıların"; 
$LANG['central'][10]="Yeni Çağrı"; 
$LANG['central'][12]="Kişisel İzleme"; 
$LANG['central'][13]="Genel İzleme"; 
$LANG['central'][14]="Grup İzleme"; 
$LANG['central'][18]="Your tickets to close"; 
$LANG['central'][19]="Your tickets to validate"; 

$LANG['choice'][0]="Hayır"; 
$LANG['choice'][1]="Evet"; 

$LANG['common'][0]="İsimsiz"; 
$LANG['common'][1]="Öğe"; 
$LANG['common'][2]="ID"; 
$LANG['common'][3]="Show the trash"; 
$LANG['common'][4]="Web"; 
$LANG['common'][5]="Üretici"; 
$LANG['common'][6]="Şablon Adı"; 
$LANG['common'][7]="Şablon seçiniz"; 
$LANG['common'][8]="Şablonları düzenle"; 
$LANG['common'][9]="Şablon ekle"; 
$LANG['common'][10]="Technician in charge of the hardware"; 
$LANG['common'][11]="Sınırlı görünüş"; 
$LANG['common'][12]="Düzen"; 
$LANG['common'][13]="Şablon"; 
$LANG['common'][14]="Sablonlar"; 
$LANG['common'][15]="Lokasyon"; 
$LANG['common'][16]="İsim"; 
$LANG['common'][17]="Tip"; 
$LANG['common'][18]="Alternate username"; 
$LANG['common'][19]="Seri Numarası"; 
$LANG['common'][20]="Envanter Numarası"; 
$LANG['common'][21]="Alternate username number"; 
$LANG['common'][22]="Model"; 
$LANG['common'][23]="İşlem başarılı"; 
$LANG['common'][24]="No selected element or badly defined operation"; 
$LANG['common'][25]="Yorum"; 
$LANG['common'][26]="Son güncelleme"; 
$LANG['common'][27]="Tarih"; 
$LANG['common'][28]="Silinmiş"; 
$LANG['common'][29]="Eklenti"; 
$LANG['common'][30]="Yeni Öğe"; 
$LANG['common'][31]="Boş Şablon"; 
$LANG['common'][32]="Özellikler"; 
$LANG['common'][33]="Toplam"; 
$LANG['common'][34]="Kullanıcı"; 
$LANG['common'][35]="Grup"; 
$LANG['common'][36]="Sınıf"; 
$LANG['common'][37]="Writer"; 
$LANG['common'][38]="Use unitary management"; 
$LANG['common'][39]="Duplicate the element as many times as there are connections"; 
$LANG['common'][40]="Do you really want to use unitary management this item ?"; 
$LANG['common'][41]="Email Uyarıları"; 
$LANG['common'][42]="Mobile phone"; 
$LANG['common'][43]="Adı"; 
$LANG['common'][44]="Default value(s)"; 
$LANG['common'][45]="MB max"; 
$LANG['common'][46]="Vcard"; 
$LANG['common'][47]="İşlem"; 
$LANG['common'][48]="Soyisim"; 
$LANG['common'][49]="Hiçbiri"; 
$LANG['common'][50]="Confirm the final deletion ?"; 
$LANG['common'][51]="İsim, Soyisim"; 
$LANG['common'][52]="Sunucu"; 
$LANG['common'][53]="Liste"; 
$LANG['common'][54]="Öğe bulunamadı"; 
$LANG['common'][55]="Bu öğeyi silmek istediğinize eminmisiniz?"; 
$LANG['common'][56]="Standard interface"; 
$LANG['common'][57]="Başlık"; 
$LANG['common'][58]="Enfazla değer"; 
$LANG['common'][59]="Genel"; 
$LANG['common'][60]="Aktif"; 
$LANG['common'][61]="Belirlenmeyen Hata"; 
$LANG['common'][62]="Diğeri"; 
$LANG['common'][63]="Hata(lar)"; 
$LANG['common'][64]="Yönetici"; 
$LANG['common'][65]="Arayüz"; 
$LANG['common'][66]="Hepsi"; 
$LANG['common'][67]="Diğerleri"; 
$LANG['common'][68]="Yatay"; 
$LANG['common'][69]="Dikey"; 
$LANG['common'][70]="Item successfully added"; 
$LANG['common'][71]="Öğe başarıyla güncellendi"; 
$LANG['common'][72]="Item successfully deleted"; 
$LANG['common'][73]="Item successfully purged"; 
$LANG['common'][74]="Item successfully restored"; 
$LANG['common'][75]="No right to make this item recursive in this entity"; 
$LANG['common'][76]="Public"; 
$LANG['common'][77]="Özel"; 
$LANG['common'][78]="Set public"; 
$LANG['common'][79]="Set personal"; 
$LANG['common'][80]="During loading..."; 
$LANG['common'][81]="Don't show deleted items"; 
$LANG['common'][82]="MB"; 
$LANG['common'][83]="You don't have permission to perform this action."; 
$LANG['common'][84]="Flag change forbidden. Linked items found."; 
$LANG['common'][85]="Change visibility in the child entities"; 
$LANG['common'][86]="You are not allowed to change the visibility flag for child entities."; 
$LANG['common'][87]="New card"; 
$LANG['common'][88]="Personal"; 
$LANG['common'][89]="Not installed"; 
$LANG['common'][90]="Object"; 
$LANG['common'][91]="Can't change this attribute. It's inherited from its parent."; 
$LANG['common'][92]="Alternate username"; 
$LANG['common'][93]="New child heading"; 

$LANG['computers'][0]="Volume"; 
$LANG['computers'][1]="Free percentage"; 
$LANG['computers'][2]="Boş Alan"; 
$LANG['computers'][3]="Global size"; 
$LANG['computers'][4]="File system"; 
$LANG['computers'][5]="Mount point"; 
$LANG['computers'][6]="Partition"; 
$LANG['computers'][7]="Add a volume"; 
$LANG['computers'][8]="Volumes"; 
$LANG['computers'][9]="Operating system"; 
$LANG['computers'][10]="Serial of the operating system"; 
$LANG['computers'][11]="Product ID of the operating system"; 
$LANG['computers'][14]="Eklendi"; 
$LANG['computers'][23]="Type of memory"; 
$LANG['computers'][24]="Memory (MB)"; 
$LANG['computers'][25]="Hard drive size"; 
$LANG['computers'][36]="Hard drive type"; 
$LANG['computers'][37]="Monitör Eklenmemiş"; 
$LANG['computers'][38]="Yazıcı Eklenmemiş"; 
$LANG['computers'][39]="Yazıcı(lar)"; 
$LANG['computers'][40]="Monitör(ler)"; 
$LANG['computers'][46]="Aygıtlar"; 
$LANG['computers'][47]="Aygit Eklenmemis"; 
$LANG['computers'][48]="Lokasyon güncellendi. Bağlantılı öğeler aynı lokasyona taşındı."; 
$LANG['computers'][49]="Alternate username updated. The connected items have been updated using this alternate username."; 
$LANG['computers'][50]="Kullanıcı veya grup güncellendi. İlişkili öğeler aynı değerlere ayarlandı."; 
$LANG['computers'][51]="Güncelleme Kaynağı"; 
$LANG['computers'][52]="Version of the operating system"; 
$LANG['computers'][53]="Servis Yamasi"; 
$LANG['computers'][54]="Telefon Eklenmemis"; 
$LANG['computers'][55]="Telefon(lar)"; 
$LANG['computers'][56]="Status updated. The connected items have been updated using this status."; 

$LANG['connect'][0]="Dogrudan baglantilar"; 
$LANG['connect'][1]="Bagli degil"; 
$LANG['connect'][15]="Bu öğeleri otomatik güncelle"; 
$LANG['connect'][16]="Dikkat!! Bu donanımın iki öğesi birbiriyle uyuşmuyor."; 

$LANG['consumables'][0]="Sarf Malzemesi"; 
$LANG['consumables'][1]="Stokta"; 
$LANG['consumables'][2]="Referans"; 
$LANG['consumables'][7]="Sarf Malzemesi Yok"; 
$LANG['consumables'][9]="Sarf Malzemesi Yok"; 
$LANG['consumables'][12]="Sarf Tipi"; 
$LANG['consumables'][13]="Yeni"; 
$LANG['consumables'][15]="Kullanilmis"; 
$LANG['consumables'][16]="Sarf Malzemesi"; 
$LANG['consumables'][20]="Yeni"; 
$LANG['consumables'][22]="Kullanilmis"; 
$LANG['consumables'][23]="Durum"; 
$LANG['consumables'][26]="Kullanim tarihi"; 
$LANG['consumables'][32]="Ver"; 
$LANG['consumables'][35]="Used consumables"; 
$LANG['consumables'][36]="Stok lokasyonu"; 
$LANG['consumables'][37]="Stoklara Don"; 
$LANG['consumables'][38]="Alert threshold"; 

$LANG['contract'][0]="Contract expired since the"; 
$LANG['contract'][1]="Contract with notice since the"; 

$LANG['crontask'][0]="Automatic actions"; 
$LANG['crontask'][1]="Synchronize equipments from OCSNG"; 
$LANG['crontask'][2]="Send alarms on cartridges"; 
$LANG['crontask'][3]="Send alarms on consumables"; 
$LANG['crontask'][4]="Send alarms on expired licenses"; 
$LANG['crontask'][5]="Send alarms on contracts"; 
$LANG['crontask'][6]="Send alarms on financial information"; 
$LANG['crontask'][7]="Clean old logs"; 
$LANG['crontask'][8]="Database optimization"; 
$LANG['crontask'][9]="Retrieve email (Mail receivers)"; 
$LANG['crontask'][10]="Check the MySQL replica"; 
$LANG['crontask'][11]="Check for new updates"; 
$LANG['crontask'][12]="Clean expired sessions"; 
$LANG['crontask'][13]="Clean generated graphics"; 
$LANG['crontask'][14]="Automatic tickets closing"; 
$LANG['crontask'][15]="Not solved tickets"; 
$LANG['crontask'][31]="Disabled"; 
$LANG['crontask'][32]="Scheduled"; 
$LANG['crontask'][33]="Running"; 
$LANG['crontask'][34]="GLPI"; 
$LANG['crontask'][35]="CLI"; 
$LANG['crontask'][36]="Run mode"; 
$LANG['crontask'][37]="Run frequency"; 
$LANG['crontask'][38]="Run period"; 
$LANG['crontask'][39]="Number of email to retrieve"; 
$LANG['crontask'][40]="Last run"; 
$LANG['crontask'][41]="Next run"; 
$LANG['crontask'][42]="As soon as possible"; 
$LANG['crontask'][43]="No action pending"; 
$LANG['crontask'][44]="Action completed, partially processed"; 
$LANG['crontask'][45]="Action completed, fully processed"; 
$LANG['crontask'][46]="Action completed, no processing required"; 
$LANG['crontask'][47]="Last run list"; 
$LANG['crontask'][48]="Start"; 
$LANG['crontask'][50]="Run count"; 
$LANG['crontask'][51]="Minimal time"; 
$LANG['crontask'][52]="Maximal time"; 
$LANG['crontask'][53]="Average time"; 
$LANG['crontask'][55]="Minimal count"; 
$LANG['crontask'][56]="Maximal count"; 
$LANG['crontask'][57]="Average count"; 
$LANG['crontask'][58]="Total count"; 
$LANG['crontask'][59]="Average speed"; 
$LANG['crontask'][60]="System lock"; 
$LANG['crontask'][61]="Disabled plugin"; 
$LANG['crontask'][62]="Elements"; 

$LANG['devices'][0]="Yeni parça ekle"; 
$LANG['devices'][1]="Hard Disk"; 
$LANG['devices'][2]="Ekran Karti"; 
$LANG['devices'][3]="Network Karti"; 
$LANG['devices'][4]="Islemci"; 
$LANG['devices'][5]="Ana Kart"; 
$LANG['devices'][6]="Memory"; 
$LANG['devices'][7]="Ses Karti"; 
$LANG['devices'][19]="Drives"; 
$LANG['devices'][20]="Controllers"; 
$LANG['devices'][21]="Diğer parçalar"; 
$LANG['devices'][22]="Cases"; 
$LANG['devices'][23]="Güç Kaynağı"; 
$LANG['devices'][24]="varsayılan"; 
$LANG['devices'][25]="Parça ekle"; 
$LANG['devices'][26]="Parça sil"; 

$LANG['device_case'][0]="Boyut"; 

$LANG['device_control'][0]="RAID"; 

$LANG['device_drive'][0]="Yazma Gucu"; 
$LANG['device_drive'][1]="Hiz"; 

$LANG['device_hdd'][0]="Rpm"; 
$LANG['device_hdd'][1]="Onbellek"; 
$LANG['device_hdd'][4]="Kapasite"; 

$LANG['device_iface'][0]="Flow"; 
$LANG['device_iface'][2]="Mac adresi"; 

$LANG['device_moboard'][0]="Chipset"; 

$LANG['device_power'][0]="Guc"; 
$LANG['device_power'][1]="ATX"; 

$LANG['device_ram'][1]="Frekans"; 
$LANG['device_ram'][2]="Kapasite"; 

$LANG['document'][1]="Checksum (SHA1)"; 
$LANG['document'][2]="Dosya"; 
$LANG['document'][3]="Başlık"; 
$LANG['document'][4]="MIME Tipi"; 
$LANG['document'][7]="Döküman Tipi"; 
$LANG['document'][9]="Uzantı"; 
$LANG['document'][10]="İkon"; 
$LANG['document'][11]="Authorized download"; 
$LANG['document'][15]="İndir"; 
$LANG['document'][16]="Döküman EKle"; 
$LANG['document'][18]="Döküman"; 
$LANG['document'][19]="İlişkili öğeler"; 
$LANG['document'][21]="İlişkilendirilmiş dökümanlar"; 
$LANG['document'][22]="Geçerli dosya"; 
$LANG['document'][23]="File too large to be added."; 
$LANG['document'][24]="Succesful deletion of the file"; 
$LANG['document'][25]="Dosya silme başarısız"; 
$LANG['document'][26]="The file is valid. Upload is successful."; 
$LANG['document'][27]="Potential upload attack, Or file too large. Moving temporary file failed."; 
$LANG['document'][28]="No file specified."; 
$LANG['document'][29]="Dizin oluşturmada hata"; 
$LANG['document'][30]="Verify that you have the correct permissions"; 
$LANG['document'][31]="Directory for documents does not exist"; 
$LANG['document'][32]="Unauthorized file type"; 
$LANG['document'][33]="Web Link"; 
$LANG['document'][34]="Dizin oluştur"; 
$LANG['document'][35]="Upload directory does not exist"; 
$LANG['document'][36]="Use a FTP installed file"; 
$LANG['document'][37]="Uygun dosya yok"; 
$LANG['document'][38]="Dosya bulunamadı"; 
$LANG['document'][39]="Document move succeeded"; 
$LANG['document'][40]="Dosya taşıma başarısız"; 
$LANG['document'][41]="Document copy succeeded"; 
$LANG['document'][42]="Ekleyen"; 
$LANG['document'][43]="Tanınmaz Dosya"; 
$LANG['document'][44]="Geçersiz dosya ismi"; 
$LANG['document'][45]="Unauthorized access to this file"; 
$LANG['document'][46]="Failure in sending the file (probably too large)"; 
$LANG['document'][48]="A document with that filename has already been attached to (another) record"; 
$LANG['document'][49]="File is altered (bad checksum)"; 
$LANG['document'][50]="Attached items"; 

$LANG['entity'][0]="Entity"; 
$LANG['entity'][2]="Root entity"; 
$LANG['entity'][3]="Associate with an entity"; 
$LANG['entity'][5]="Automatic computer assignment"; 
$LANG['entity'][6]="Otomatik kullanıcı atama"; 
$LANG['entity'][7]="tree structure"; 
$LANG['entity'][8]="By entity"; 
$LANG['entity'][9]="Child entities"; 
$LANG['entity'][10]="Select the desired entity"; 
$LANG['entity'][11]="to see the entity and its sub-entities"; 
$LANG['entity'][12]="LDAP attribute identifying entity"; 
$LANG['entity'][13]="TAG identifying entity"; 
$LANG['entity'][14]="Advanced informations"; 
$LANG['entity'][15]="LDAP directory of an entity"; 
$LANG['entity'][16]="Search filter (if needed)"; 
$LANG['entity'][17]="Automatic closing configuration"; 
$LANG['entity'][18]="Automatic closing of the tickets after"; 

$LANG['event'][0]="Source"; 
$LANG['event'][2]="Servis"; 
$LANG['event'][3]="Seviye"; 
$LANG['event'][4]="Mesaj"; 
$LANG['event'][18]="Alan"; 
$LANG['event'][19]="Güncelle"; 
$LANG['event'][20]="No historical"; 

$LANG['financial'][1]="Sözleşme"; 
$LANG['financial'][2]="Lifelong"; 
$LANG['financial'][3]="Finansal bilgi"; 
$LANG['financial'][4]="Sayı"; 
$LANG['financial'][5]="Maliyet"; 
$LANG['financial'][6]="Sözleşme Tipi"; 
$LANG['financial'][8]="Duration"; 
$LANG['financial'][9]="Yıl"; 
$LANG['financial'][10]="Notice"; 
$LANG['financial'][11]="Fatura periyodu"; 
$LANG['financial'][13]="Hesap numarası"; 
$LANG['financial'][14]="Alım tarihi"; 
$LANG['financial'][15]="Warranty duration"; 
$LANG['financial'][16]="Garanti bilgisi"; 
$LANG['financial'][18]="Order number"; 
$LANG['financial'][19]="Delivery form"; 
$LANG['financial'][20]="Immobilization number"; 
$LANG['financial'][21]="Değer"; 
$LANG['financial'][22]="Amortisman tipi"; 
$LANG['financial'][23]="Amortisman süresi"; 
$LANG['financial'][24]="İrtibat ekle"; 
$LANG['financial'][25]="Tedarikçi Ekle"; 
$LANG['financial'][26]="Tedarikçi"; 
$LANG['financial'][30]="Faks"; 
$LANG['financial'][33]="İrtibat ekle"; 
$LANG['financial'][36]="Sözleşme Ekle"; 
$LANG['financial'][42]="Ticari"; 
$LANG['financial'][43]="Teknisyen"; 
$LANG['financial'][44]="Adres"; 
$LANG['financial'][45]="Web sitesi"; 
$LANG['financial'][46]="İlişkilendirilmiş irtibatlar"; 
$LANG['financial'][47]="Linear"; 
$LANG['financial'][48]="Azalış"; 
$LANG['financial'][50]="Emanet"; 
$LANG['financial'][51]="Renting"; 
$LANG['financial'][52]="Leasing"; 
$LANG['financial'][53]="Insurance"; 
$LANG['financial'][54]="Donanım Destek"; 
$LANG['financial'][55]="Yazılım desteği"; 
$LANG['financial'][56]="Service provided"; 
$LANG['financial'][57]="Ay"; 
$LANG['financial'][59]="Müşteri Destek Saatleri"; 
$LANG['financial'][60]="Hafta içi"; 
$LANG['financial'][61]="Cumartesi"; 
$LANG['financial'][62]="Pazar ve Tatiller"; 
$LANG['financial'][65]="İlişkilendirilmiş tedarikçiler"; 
$LANG['financial'][66]="İlişkili sözleşmeler"; 
$LANG['financial'][68]="Finansal bilgileri aktif et"; 
$LANG['financial'][69]="Sözleşme periyodu"; 
$LANG['financial'][76]="Startup date"; 
$LANG['financial'][77]="Amortisman katsayısı"; 
$LANG['financial'][78]="Garanti bitiş değeri"; 
$LANG['financial'][79]="Third party Type"; 
$LANG['financial'][80]="Garanti bitiş tarihi"; 
$LANG['financial'][81]="Net hesap değeri"; 
$LANG['financial'][82]="Fatura (Hesap) numarası"; 
$LANG['financial'][83]="Max number of items"; 
$LANG['financial'][84]="For this type of element, the financial information is only a model for the elements which you should add."; 
$LANG['financial'][85]="Talep edilen öğe bulunamadı!"; 
$LANG['financial'][86]="End of contract"; 
$LANG['financial'][87]="Bütçe"; 
$LANG['financial'][88]="Valid to:"; 
$LANG['financial'][89]="TCO(miktar+takip maliyeti)"; 
$LANG['financial'][90]="Monthly TCO"; 
$LANG['financial'][91]="TCO"; 
$LANG['financial'][92]="ANV"; 
$LANG['financial'][93]="Sözleşmesi bitenler - Son 30 günde"; 
$LANG['financial'][94]="Sözleşme bitimine 7 günden az kalanlar"; 
$LANG['financial'][95]="Sözleşme bitimine 30 günden az kalanlar"; 
$LANG['financial'][96]="Contracts where notice begins in less than 7 days"; 
$LANG['financial'][97]="Contracts where notice begins in less than 30 days"; 
$LANG['financial'][98]="Sona erme"; 
$LANG['financial'][99]="Sona erme + uyarı"; 
$LANG['financial'][100]="Posta Kodu"; 
$LANG['financial'][101]="Şehir"; 
$LANG['financial'][102]="State"; 
$LANG['financial'][103]="Ülke"; 
$LANG['financial'][104]="İlişkili öğeler"; 
$LANG['financial'][105]="Tacit"; 
$LANG['financial'][106]="Express"; 
$LANG['financial'][107]="Renewal"; 
$LANG['financial'][108]="Total spent on the budget"; 
$LANG['financial'][109]="Total remaining on the budget"; 
$LANG['financial'][110]="Budgets"; 

$LANG['gmt'][0]="GMT"; 
$LANG['gmt'][1]="saat"; 
$LANG['gmt'][2]="h"; 

$LANG['help'][1]="Matrix of calculus for priority"; 
$LANG['help'][2]="Major"; 
$LANG['help'][3]="Çok Yüksek"; 
$LANG['help'][4]="Yüksek"; 
$LANG['help'][5]="Orta"; 
$LANG['help'][6]="Az"; 
$LANG['help'][7]="Çok Az"; 
$LANG['help'][8]="Gelişmelerden haberdar et"; 
$LANG['help'][11]="E-mail"; 
$LANG['help'][14]="Sorunu Kaydet"; 
$LANG['help'][16]="If you want be notified about the action(s) taken, please enter your e-mail address."; 
$LANG['help'][18]="Mesajınız kaydedilip talebiniz değerlendirmeye alınmıştır."; 
$LANG['help'][19]="Kullanıcı Yardım Sistemini kullandığınız için teşekkür ederiz."; 
$LANG['help'][22]="Bilgisayar ID si ara"; 
$LANG['help'][23]="Enter the first letters (user, item name, serial or asset number)"; 
$LANG['help'][24]="Donanım Tipi"; 
$LANG['help'][25]="Bilgisayar"; 
$LANG['help'][26]="Ağ aygıtı"; 
$LANG['help'][27]="Yazıcı"; 
$LANG['help'][28]="Monitör"; 
$LANG['help'][29]="Aygıt"; 
$LANG['help'][30]="Genel"; 
$LANG['help'][31]="Yazılım"; 
$LANG['help'][35]="Telefon"; 
$LANG['help'][40]="Çağrının başlığı yok, tekrar deneyiniz."; 
$LANG['help'][41]="Çağrınızda sınıf yok, tekrar deneyiniz"; 
$LANG['help'][42]="Very High"; 
$LANG['help'][43]="High"; 
$LANG['help'][44]="Medium"; 
$LANG['help'][45]="Low"; 
$LANG['help'][46]="Very Low"; 
$LANG['help'][47]="Very High"; 
$LANG['help'][48]="High"; 
$LANG['help'][49]="Medium"; 
$LANG['help'][50]="Low"; 
$LANG['help'][51]="Very Low"; 

$LANG['install'][0]="GLPI kurulumu veya güncellemesi"; 
$LANG['install'][1]="Choose 'Install' for a completely new installation of GLPI."; 
$LANG['install'][2]="Select 'Update' to update your version of GLPI from an earlier version"; 
$LANG['install'][3]="Kurulum"; 
$LANG['install'][4]="Güncelle"; 
$LANG['install'][5]="Checking of the compatibility of your environment with the execution of GLPI"; 
$LANG['install'][6]="Test done"; 
$LANG['install'][7]="Sonuç"; 
$LANG['install'][8]="Testing PHP Parser"; 
$LANG['install'][9]="You must install at least PHP5."; 
$LANG['install'][10]="GLPI is not compatible with the option zend.ze1_compatibility_mode = On."; 
$LANG['install'][11]="PHP version is at least 5.x - Perfect !"; 
$LANG['install'][12]="Session testi"; 
$LANG['install'][13]="Your PHP parser was not compiled with sessions support !"; 
$LANG['install'][14]="Session desteği var - Uygun !"; 
$LANG['install'][15]="Php.ini de session desteğinin aktif olduğundan emin olunuz."; 
$LANG['install'][16]="Checking write permissions for dump files"; 
$LANG['install'][17]="Dosya oluşturulamadı."; 
$LANG['install'][18]="Unofficial translations are also available"; 
$LANG['install'][19]="Dozya oluşturuldu ama silinemiyor."; 
$LANG['install'][20]="Bir dosya ve klasör oluşturuldu ve silindi. Uygun!"; 
$LANG['install'][21]="Döküman dosyalarını yazmak için yetki kontrolü yapılıyor"; 
$LANG['install'][22]="Dosya oluşturuldu. Tamam !"; 
$LANG['install'][23]="Checking write permissions for setting files"; 
$LANG['install'][24]="Initialization of the database"; 
$LANG['install'][25]="Devam?"; 
$LANG['install'][26]="Devam"; 
$LANG['install'][27]="Tekrar Deneyin"; 
$LANG['install'][28]="Veritabanı bağlantı ayarı"; 
$LANG['install'][29]="Veritabanı bağlantı parametreleri"; 
$LANG['install'][30]="Mysql server"; 
$LANG['install'][31]="Mysql user"; 
$LANG['install'][32]="Mysql password"; 
$LANG['install'][34]="Veritabanı bağlantısı testi"; 
$LANG['install'][35]="Veri tabanına bağlanılamıyor"; 
$LANG['install'][36]="Sunucu cevapladı"; 
$LANG['install'][37]="The server or/and user field is empty"; 
$LANG['install'][38]="Bir veritabanı seçiniz:"; 
$LANG['install'][39]="Yeni bir veritabanı oluştur veya mevcudu kullan:"; 
$LANG['install'][40]="Güncellenecek veritabanını seçiniz:"; 
$LANG['install'][41]="Bu veritabanını kullanmak imkansız:"; 
$LANG['install'][43]="Tamam - veritabanı sıfırlandı"; 
$LANG['install'][47]="Veritabanı ayar dosyasına yazılamıyor."; 
$LANG['install'][48]="Veritabanı oluşturmada hata"; 
$LANG['install'][49]="Veritabanı seçmediniz!"; 
$LANG['install'][50]="Checking write permissions for session files"; 
$LANG['install'][52]="Check write permissions for automatic actions files"; 
$LANG['install'][53]="Log dosyasına yazma test ediliyor"; 
$LANG['install'][55]="Kurulum tamamlandı"; 
$LANG['install'][57]="Default logins / passwords are:"; 
$LANG['install'][58]="'glpi/glpi' yönetici hesap bilgileridir."; 
$LANG['install'][59]="teknik hesap: tech/tech"; 
$LANG['install'][60]="normal/normal for the normal account"; 
$LANG['install'][61]="post-only/postonly for the postonly account"; 
$LANG['install'][62]="You can delete or modify these accounts as well as the initial data."; 
$LANG['install'][64]="GLPI kullan"; 
$LANG['install'][65]="'magic_quotes_sybase' uzantısı testi"; 
$LANG['install'][66]="GLPI does not work with the magic_quotes_sybase option ; Please turn it off and retry"; 
$LANG['install'][67]="magic_quotes_sybase seçeneği sunucuda aktif değil - Uygun!"; 
$LANG['install'][68]="Test session auto start"; 
$LANG['install'][69]="session.auto_start is activated. See .htaccess file in the GLPI root for more information."; 
$LANG['install'][70]="Veritabanı bağlantı dosyası oluşturulamadı, dosya izinlerini kontrol ediniz."; 
$LANG['install'][71]="Mysql uzantı testi"; 
$LANG['install'][72]="PHP'yi Mysql eklentisi ile derlemelisiniz"; 
$LANG['install'][73]="mysql_query()fonksiyonu var - Uygun!"; 
$LANG['install'][74]="'Session_use_trans_sid' parametresi kullanımı testi"; 
$LANG['install'][75]="Php.ini de 'Session_use_trans_id option' parametersini kullanılmaz yapmalısınız"; 
$LANG['install'][76]="Session çalıştı, trans_id problemi yok - Uygun!"; 
$LANG['install'][77]="Adım"; 
$LANG['install'][81]="Kurulum başlangıcı"; 
$LANG['install'][82]="Veritabanı oluşturuldu"; 
$LANG['install'][85]="Fonsiyonellik var - Uygun !"; 
$LANG['install'][86]="Tahsis edilmiş hafıza testi"; 
$LANG['install'][87]="Tahsis edilmiş hafıza:"; 
$LANG['install'][88]="A minimum of 64MB is commonly required for GLPI."; 
$LANG['install'][89]="Tamam !"; 
$LANG['install'][90]="php.ini dosyasındaki memory_limit parametresini artırmanız gerekmekte."; 
$LANG['install'][91]="Allocated memory > 64M"; 
$LANG['install'][92]="Lisans"; 
$LANG['install'][93]="Yukarda yazılı olan lisansla ilgili şartları okudum ve kabul ettim."; 
$LANG['install'][94]="Yukarda lisansla ilgili yazılan bilgileri okudum ve KABUL ETMEDİM"; 
$LANG['install'][95]="Sınırsız Bellek"; 
$LANG['install'][96]="Sınırsız Bellek"; 
$LANG['install'][97]="Check permissions to the directory:"; 
$LANG['install'][99]="Cache dosyalarını yazmak için yetki kontrolü yapılıyor"; 
$LANG['install'][100]="Dizin oluşturulamadı"; 
$LANG['install'][101]="Dizin oluşturuldu ama kaldırılamıyor."; 
$LANG['install'][102]="Test json functions"; 
$LANG['install'][103]="GLPI can't work correctly without the json_encode and json_decode functions"; 
$LANG['install'][104]="mbstring extension test"; 
$LANG['install'][105]="Mbstring extension of your parser PHP is not installed"; 
$LANG['install'][106]="Checking write permissions for graphic files"; 

$LANG['job'][2]="by"; 
$LANG['job'][4]="Talep eden"; 
$LANG['job'][5]="Atanan:"; 
$LANG['job'][6]="Teknisyen"; 
$LANG['job'][7]="Task"; 
$LANG['job'][8]="last(s) ticket(s)"; 
$LANG['job'][9]="Follow-up"; 
$LANG['job'][11]="Describe the Problem/Action"; 
$LANG['job'][12]="Bu çağrı için işlem yok"; 
$LANG['job'][13]="New ticket"; 
$LANG['job'][15]="Solved"; 
$LANG['job'][19]="Email takipleri"; 
$LANG['job'][20]="Toplam Zaman"; 
$LANG['job'][21]="Saat"; 
$LANG['job'][22]="Dakika"; 
$LANG['job'][29]="Yeni bir işlem ekle"; 
$LANG['job'][30]="Add a new task"; 
$LANG['job'][31]="Duration"; 
$LANG['job'][32]="Hiçbiri"; 
$LANG['job'][33]="Açıklama yok"; 
$LANG['job'][34]="Plan this task"; 
$LANG['job'][35]="Planlama"; 
$LANG['job'][37]="Özet"; 
$LANG['job'][38]="Çağrı"; 
$LANG['job'][39]="Takibi güncelle"; 
$LANG['job'][40]="Zaman Maliyeti"; 
$LANG['job'][41]="Sabit Maliyet"; 
$LANG['job'][42]="Malzeme Gideri"; 
$LANG['job'][43]="Toplam Maliyet"; 
$LANG['job'][44]="Talep kaynağı"; 
$LANG['job'][45]="Source of follow-up"; 
$LANG['job'][46]="The ticket will be added in the entity"; 
$LANG['job'][47]="Costs"; 
$LANG['job'][48]="Type of solution"; 
$LANG['job'][49]="New task"; 
$LANG['job'][50]="No task for this ticket"; 
$LANG['job'][51]="Approval of the solution"; 
$LANG['job'][52]="Update task"; 
$LANG['job'][53]="Deletion of a task"; 
$LANG['job'][54]="Without a reply, the ticket will be automatically closed after"; 

$LANG['joblist'][0]="Durum"; 
$LANG['joblist'][1]="Just my ones"; 
$LANG['joblist'][2]="Öncelik"; 
$LANG['joblist'][3]="Personal + group(s)"; 
$LANG['joblist'][4]="Atandı"; 
$LANG['joblist'][6]="Açıklama"; 
$LANG['joblist'][7]="Bu öğe için yeni çağrı"; 
$LANG['joblist'][8]="Çağrı Bulunamadı"; 
$LANG['joblist'][9]="Yeni"; 
$LANG['joblist'][10]="Kapandı (Çözüldü)"; 
$LANG['joblist'][11]="Kayıt tarihi"; 
$LANG['joblist'][12]="Closed on"; 
$LANG['joblist'][13]="Tickets to be processed"; 
$LANG['joblist'][14]="Solved on"; 
$LANG['joblist'][16]="No ticket in progress."; 
$LANG['joblist'][17]="Kapandı (Çözülmedi)"; 
$LANG['joblist'][18]="İşlemde (atanmış)"; 
$LANG['joblist'][19]="Processing (planned)"; 
$LANG['joblist'][21]="Processing"; 
$LANG['joblist'][26]="Bekleyen"; 
$LANG['joblist'][27]="Takip için E-mail"; 
$LANG['joblist'][28]="Tickets on linked items"; 
$LANG['joblist'][29]="Urgency"; 
$LANG['joblist'][30]="Impact"; 
$LANG['joblist'][32]="Solved"; 
$LANG['joblist'][33]="Closed"; 
$LANG['joblist'][34]="Not solved"; 
$LANG['joblist'][35]="Not closed"; 
$LANG['joblist'][36]="Status value in database"; 

$LANG['jobresolution'][1]="Solution"; 
$LANG['jobresolution'][3]="Approved solution"; 
$LANG['jobresolution'][4]="Refused solution"; 
$LANG['jobresolution'][5]="If you reject the solution, you must specify a reason"; 

$LANG['knowbase'][1]="SSS"; 
$LANG['knowbase'][5]="Put this item in the FAQ"; 
$LANG['knowbase'][6]="Bu öğe için bir sınıf seçiniz :"; 
$LANG['knowbase'][7]="Delete this item from the FAQ"; 
$LANG['knowbase'][8]="Bu öğeyi düzenle"; 
$LANG['knowbase'][9]="Bu öğeyi sil"; 
$LANG['knowbase'][10]="This item is part of the FAQ"; 
$LANG['knowbase'][11]="This item is not part of the FAQ"; 
$LANG['knowbase'][12]="Root"; 
$LANG['knowbase'][13]="Sınıf ismi"; 
$LANG['knowbase'][14]="Konu"; 
$LANG['knowbase'][15]="İçerik"; 
$LANG['knowbase'][24]="Sık sorulan sorulara giriş"; 
$LANG['knowbase'][26]="Views"; 
$LANG['knowbase'][27]="On"; 
$LANG['knowbase'][29]="En Güncel Konu"; 
$LANG['knowbase'][30]="Güncel sorular"; 

$LANG['ldap'][0]="Bulk import users from a LDAP directory"; 
$LANG['ldap'][1]="Önceden aktarılmış kullanıcıları eşitle"; 
$LANG['ldap'][2]="Yeni kullanıcıları aktar"; 
$LANG['ldap'][3]="Aktarilacak kullanici yok"; 
$LANG['ldap'][4]="LDAP dizin seçimi"; 
$LANG['ldap'][5]="Kullanicilari aktaracaginiz LDAP sunucuyu seciniz"; 
$LANG['ldap'][6]="LDAP sunucusuyla iletisim kurulamiyor"; 
$LANG['ldap'][7]="GLPI'da LDAP sunucu tanimlanmamis"; 
$LANG['ldap'][8]="Warning: The request exceeds the limit of the directory. The results are only partial."; 
$LANG['ldap'][9]="Ldap baglanti testi"; 
$LANG['ldap'][12]="Eşitleme"; 
$LANG['ldap'][13]="in the LDAP directory"; 
$LANG['ldap'][14]="GLPI'da"; 
$LANG['ldap'][15]="Eşitle"; 
$LANG['ldap'][16]="Önayar"; 
$LANG['ldap'][17]="Active Directory"; 
$LANG['ldap'][18]="List of LDAP directory replicates"; 
$LANG['ldap'][19]="Benzet"; 
$LANG['ldap'][20]="Add a LDAP directory replica"; 
$LANG['ldap'][21]="Ana sunucu"; 
$LANG['ldap'][22]="Benzet"; 
$LANG['ldap'][23]="Bulk import groups from a LDAP directory"; 
$LANG['ldap'][24]="Yeni gruplari aktar"; 
$LANG['ldap'][25]="Aktarılacak grup yok"; 
$LANG['ldap'][30]="How LDAP aliases should be handled"; 
$LANG['ldap'][31]="Never dereferenced (default)"; 
$LANG['ldap'][32]="Always dereferenced"; 
$LANG['ldap'][33]="Dereferenced during the search (but not when locating)"; 
$LANG['ldap'][34]="Dereferenced when locating (not during the search)"; 
$LANG['ldap'][35]="Import an user"; 
$LANG['ldap'][36]="No directory associated to entity : search impossible"; 
$LANG['ldap'][38]="Search criterias for users"; 
$LANG['ldap'][39]="Advanced"; 
$LANG['ldap'][40]="Simple"; 
$LANG['ldap'][41]="To change"; 
$LANG['ldap'][42]="No directory selected"; 
$LANG['ldap'][43]="No users to be synchronized"; 
$LANG['ldap'][44]="Default server"; 
$LANG['ldap'][45]="Action when a user is deleted from the LDAP directory"; 
$LANG['ldap'][46]="Withdraw accreditations and groups (dynamics)"; 
$LANG['ldap'][47]="Put in trash"; 
$LANG['ldap'][48]="Deleted user in LDAP directory"; 
$LANG['ldap'][49]="View users added since"; 
$LANG['ldap'][50]="View users updated since"; 
$LANG['ldap'][52]="Less than"; 
$LANG['ldap'][53]="More than"; 
$LANG['ldap'][54]="Enable filtering by date"; 
$LANG['ldap'][55]="Disable filtering by date"; 
$LANG['ldap'][56]="Weeks"; 

$LANG['links'][1]="Bağlantı veya dosya adı"; 
$LANG['links'][4]="Donanım tipi ilişkilendrilmiş"; 
$LANG['links'][6]="Valid tags"; 
$LANG['links'][7]="Bağlantı tanımsız"; 
$LANG['links'][9]="Dosya içeriği"; 

$LANG['log'][1]="Sistem"; 
$LANG['log'][16]="Planlama"; 
$LANG['log'][18]="parçalar"; 
$LANG['log'][20]="Öğe eklendi"; 
$LANG['log'][21]="Öğeyi güncelle"; 
$LANG['log'][22]="Öğeyi sil"; 
$LANG['log'][23]="restoration of an item"; 
$LANG['log'][24]="purge item"; 
$LANG['log'][26]="Öğenin bağlantısını kes"; 
$LANG['log'][27]="Öğe bağlantısı"; 
$LANG['log'][28]="Parçaları güncelle"; 
$LANG['log'][29]="approval/refusal of the solution"; 
$LANG['log'][30]="Tipi ilişkilendir"; 
$LANG['log'][31]="Tip sil"; 
$LANG['log'][32]="add a link with an item"; 
$LANG['log'][33]="Öğe ile olan bağlantıyı sil"; 
$LANG['log'][34]="Tedarikçi ile bağlantı ekle"; 
$LANG['log'][35]="tedarikçi ile olan bağı sil"; 
$LANG['log'][40]="IP bağlantısı"; 
$LANG['log'][41]="Bağlantı hatasi"; 
$LANG['log'][42]="Rezervasyon"; 
$LANG['log'][44]="Başlık"; 
$LANG['log'][45]="Başarılı"; 
$LANG['log'][46]="Başarısız"; 
$LANG['log'][48]="Kullanıcıyı gruba ekle"; 
$LANG['log'][49]="Kullanıcıyı gruptan sil"; 
$LANG['log'][55]="Bağlantı"; 
$LANG['log'][59]="Automatic action"; 
$LANG['log'][60]="use unitary management for this item"; 
$LANG['log'][61]="add a user to an entity"; 
$LANG['log'][62]="Bu kullanıcıyı tamamen sil"; 
$LANG['log'][64]="modification of field"; 
$LANG['log'][65]="Kural"; 
$LANG['log'][66]="Güvenlik"; 
$LANG['log'][67]="Not değişikliği"; 
$LANG['log'][70]="Ağ portu eklendi"; 
$LANG['log'][71]="Birçok ağ portu eklendi"; 
$LANG['log'][73]="Ağ portu silindi"; 
$LANG['log'][74]="Birçok ağ portu silindi"; 
$LANG['log'][75]="Ağ portu taşındı"; 
$LANG['log'][77]="associate a VLAN to a network port"; 
$LANG['log'][78]="associate a VLAN to several ports"; 
$LANG['log'][79]="vlan dissociated from a network port"; 
$LANG['log'][80]="dissociation of a VLAN from multiple network ports"; 
$LANG['log'][82]="versiyon ekleme"; 
$LANG['log'][83]="modification of version"; 
$LANG['log'][84]="version's deletion"; 
$LANG['log'][85]="Lisans ekleme"; 
$LANG['log'][86]="modification of licence"; 
$LANG['log'][87]="licence's deletion"; 
$LANG['log'][88]="Kartuş eklendi"; 
$LANG['log'][89]="adding consumables"; 
$LANG['log'][90]="deletion of a cartridge"; 
$LANG['log'][91]="deletion of a consumable"; 
$LANG['log'][92]="restoration of a cartridge"; 
$LANG['log'][93]="restoration of a consumable"; 
$LANG['log'][94]="cartridge's update"; 
$LANG['log'][95]="cartridge's installation"; 
$LANG['log'][96]="cartridge's uninstallation"; 
$LANG['log'][97]="consumable out for the user"; 
$LANG['log'][98]="add an element"; 
$LANG['log'][99]="modification of an item"; 
$LANG['log'][100]="deletion of an item"; 

$LANG['login'][0]="Son giriş"; 
$LANG['login'][1]="Tekrar Giriş Yapın"; 
$LANG['login'][2]="LDAP directory"; 
$LANG['login'][3]="IMAP/POP"; 
$LANG['login'][4]="CAS"; 
$LANG['login'][5]="Giriş onaylanmadı"; 
$LANG['login'][6]="Kullanıcı Adı"; 
$LANG['login'][7]="Parola"; 
$LANG['login'][8]="Boş kullanıcı veya parola"; 
$LANG['login'][9]="Henüz yetkilendirilmedi."; 
$LANG['login'][10]="Yetkilendirme"; 
$LANG['login'][11]="GLPI'a bağlantı için kullanıcı yetkisi yok"; 
$LANG['login'][12]="Kullanıcı adı veya paralo hatalı!!"; 
$LANG['login'][13]="Parola alanı boş"; 
$LANG['login'][14]="Tanımsız kullanıcı"; 
$LANG['login'][15]="User not found or several users found"; 
$LANG['login'][16]="unsuccessful authorization in LDAP"; 
$LANG['login'][18]="GLPI internal database"; 
$LANG['login'][20]="You do not have access to this application because your account was deactivated or removed"; 
$LANG['login'][21]="IMAP/POP sunucusuna bağlantı kontrolü"; 
$LANG['login'][22]="Deneme başarılı"; 
$LANG['login'][23]="Deneme başarısız"; 
$LANG['login'][24]="Son giriş tarihi"; 
$LANG['login'][25]="Bağlanmak için yetkiniz yok"; 
$LANG['login'][26]="İnternet gezgini uygulamanızda JavaScript özelliğini aktif hale getirmelisiniz."; 
$LANG['login'][27]="Bu uygulamayı kullanabilmeniz için cookie kabul etmeniz gerekmektedir."; 
$LANG['login'][30]="Yetkilendirme metodunu değiştir"; 
$LANG['login'][31]="Authentication on a LDAP directory"; 
$LANG['login'][32]="GLPI veritabanında yetkilendirme"; 
$LANG['login'][33]="Imap/Pop sunucuda yetkilendirme"; 

$LANG['mailgate'][0]="Mail Receiver"; 
$LANG['mailgate'][2]="Mail çağrılarını şimdi al"; 
$LANG['mailgate'][3]="Number of available and retrieved emails"; 
$LANG['mailgate'][4]="mbstring extension not found. Warning with charsets used."; 
$LANG['mailgate'][5]="Eklenen dosya geçersiz"; 
$LANG['mailgate'][6]="Eklenen dosya çok büyük"; 
$LANG['mailgate'][7]="Maximum size of each file imported by the mail receiver"; 
$LANG['mailgate'][9]="Your email could not be processed.\nIf the problem persists, contact the administrator"; 
$LANG['mailgate'][10]="Email refused"; 
$LANG['mailgate'][11]="Process of emails import"; 
$LANG['mailgate'][12]="Unable to affect the email to an entity"; 
$LANG['mailgate'][13]="Reason of rebuff"; 
$LANG['mailgate'][14]="Email not found. Impossible import"; 
$LANG['mailgate'][16]="Re:"; 

$LANG['mailing'][0]="----------------------------------------------------------"; 
$LANG['mailing'][1]="======================================================================"; 
$LANG['mailing'][4]="Already done followup(s)"; 
$LANG['mailing'][5]="Çağrı açıklaması"; 
$LANG['mailing'][10]="Yeni çağrının takibi"; 
$LANG['mailing'][12]="Çağrının atandığı kişi:"; 
$LANG['mailing'][14]="Çağrının sınıfını güncelle"; 
$LANG['mailing'][15]="Çağrının önceliğini güncelle"; 
$LANG['mailing'][17]="Çağrının öğesini güncelle"; 
$LANG['mailing'][18]="Çağrının yazarını güncelle"; 
$LANG['mailing'][19]="Yeni rezervasyon"; 
$LANG['mailing'][20]="Çağrının grubunu güncelle"; 
$LANG['mailing'][21]="Çağrı kaynağında değişiklik"; 
$LANG['mailing'][23]="Rezervasyon değişikliği"; 
$LANG['mailing'][26]="Eklenen döküman:"; 
$LANG['mailing'][27]="Çağrının durumunu güncelle"; 
$LANG['mailing'][29]="Rezervasyon iptali"; 
$LANG['mailing'][30]="Çağrı Güncellendi"; 
$LANG['mailing'][31]="Bu E-mail Mail sisteminin çalışmasını test amacıyla gönderilmiştir"; 
$LANG['mailing'][32]="Mail test"; 
$LANG['mailing'][33]="Kartuş/Toner alarmı"; 
$LANG['mailing'][35]="Threshold of alarm reached for the type of consumable:"; 
$LANG['mailing'][36]="Sarf Malzeme Alarmı"; 
$LANG['mailing'][37]="Contract entered in notice time:"; 
$LANG['mailing'][39]="Sözleşme alarrmı"; 
$LANG['mailing'][40]="Öğe garanti süresini doldurdu."; 
$LANG['mailing'][41]="Finansal Bilgilendirme Alarmı"; 
$LANG['mailing'][42]="Saat maliyetinde değişiklik"; 
$LANG['mailing'][43]="Sabit maliyette değişiklik"; 
$LANG['mailing'][44]="Malzeme maliyetinde değişiklik"; 
$LANG['mailing'][45]="Çağrı başlığını değiştir"; 
$LANG['mailing'][46]="Çağrı açıklamasını değiştir"; 
$LANG['mailing'][47]="Email göndermede hata var"; 
$LANG['mailing'][48]="Açılma tarihinde değişiklik"; 
$LANG['mailing'][49]="Kapanma tarihinde değişiklik"; 
$LANG['mailing'][50]="Çağrı alıcısını değiştir"; 
$LANG['mailing'][51]="Expired license :"; 
$LANG['mailing'][53]="Change of solution"; 
$LANG['mailing'][54]="Expiry date"; 
$LANG['mailing'][100]="Sınıf tanımlanmamış"; 
$LANG['mailing'][101]="Email ile takip hizmette."; 
$LANG['mailing'][102]="Email ile takip hizmet dışı bırakıldı."; 
$LANG['mailing'][104]="Takip süresi"; 
$LANG['mailing'][105]="Atanan"; 
$LANG['mailing'][107]="Nothing"; 
$LANG['mailing'][109]="Grup yok"; 
$LANG['mailing'][110]="Yanlış Email"; 
$LANG['mailing'][113]="Notification templates"; 
$LANG['mailing'][114]="Body"; 
$LANG['mailing'][115]="Main part of email"; 
$LANG['mailing'][116]="HTML"; 
$LANG['mailing'][117]="text"; 
$LANG['mailing'][118]="Email"; 
$LANG['mailing'][119]="Occurrence"; 
$LANG['mailing'][120]="Notification method"; 
$LANG['mailing'][121]="Recipients"; 
$LANG['mailing'][122]="Task(s) already done"; 
$LANG['mailing'][123]="Solved ticket"; 
$LANG['mailing'][124]="Add a new translation"; 
$LANG['mailing'][125]="Default translation"; 
$LANG['mailing'][126]="Template translation"; 
$LANG['mailing'][127]="Closing of the ticket"; 
$LANG['mailing'][128]="leave the field empty for a generation from HTML"; 
$LANG['mailing'][129]="Deletion of a ticket"; 
$LANG['mailing'][130]="From"; 
$LANG['mailing'][131]="Recipient"; 
$LANG['mailing'][132]="Email header"; 
$LANG['mailing'][133]="Delete email(s)"; 
$LANG['mailing'][134]="Updating follow-up"; 
$LANG['mailing'][135]="Follow-up's deletion"; 
$LANG['mailing'][136]="Reservation expired"; 
$LANG['mailing'][137]="Hardware user"; 
$LANG['mailing'][138]="List of available tags"; 
$LANG['mailing'][139]="Label"; 
$LANG['mailing'][140]="Tag"; 
$LANG['mailing'][141]="Followups"; 
$LANG['mailing'][142]="Tasks"; 
$LANG['mailing'][143]="Validations"; 
$LANG['mailing'][144]="Historical"; 
$LANG['mailing'][145]="List of values"; 
$LANG['mailing'][146]="Single value"; 
$LANG['mailing'][147]="Possible value(s)"; 

$LANG['Menu'][0]="Bilgisayar"; 
$LANG['Menu'][1]="Ağ"; 
$LANG['Menu'][2]="Yazıcı"; 
$LANG['Menu'][3]="Monitör"; 
$LANG['Menu'][4]="Yazılım"; 
$LANG['Menu'][5]="Tickets"; 
$LANG['Menu'][6]="Rapor"; 
$LANG['Menu'][11]="Ayarlar"; 
$LANG['Menu'][12]="Maintenance"; 
$LANG['Menu'][13]="İstatistik"; 
$LANG['Menu'][14]="Kullanıcı"; 
$LANG['Menu'][15]="Teknik Yönetim"; 
$LANG['Menu'][16]="Aygıt"; 
$LANG['Menu'][17]="Rezervasyon"; 
$LANG['Menu'][18]="Araçlar"; 
$LANG['Menu'][19]="Knowledge base"; 
$LANG['Menu'][20]="SSS"; 
$LANG['Menu'][21]="Kartuş"; 
$LANG['Menu'][22]="İrtibat"; 
$LANG['Menu'][23]="Tedarikçi"; 
$LANG['Menu'][24]="Finansal Bilgiler"; 
$LANG['Menu'][25]="Sözleşme"; 
$LANG['Menu'][26]="Yönetim"; 
$LANG['Menu'][27]="Döküman"; 
$LANG['Menu'][28]="Durum"; 
$LANG['Menu'][29]="Planlama"; 
$LANG['Menu'][30]="Log"; 
$LANG['Menu'][31]="Simplified interface"; 
$LANG['Menu'][32]="Sarf Malzeme"; 
$LANG['Menu'][33]="OCSNG"; 
$LANG['Menu'][34]="Telefon"; 
$LANG['Menu'][35]="Profil"; 
$LANG['Menu'][36]="Grup"; 
$LANG['Menu'][37]="Entities"; 
$LANG['Menu'][38]="Envanter"; 
$LANG['Menu'][39]="Receivers"; 
$LANG['Menu'][40]="Yerimi"; 
$LANG['Menu'][41]="Rights"; 

$LANG['monitors'][14]="Mikrofon"; 
$LANG['monitors'][15]="Speaker"; 
$LANG['monitors'][18]="Özellikler"; 
$LANG['monitors'][19]="Sub-D"; 
$LANG['monitors'][20]="BNC"; 
$LANG['monitors'][21]="Ebat"; 
$LANG['monitors'][32]="DVI"; 
$LANG['monitors'][33]="Pivot"; 

$LANG['networking'][4]="Network port"; 
$LANG['networking'][5]="Memory (MB)"; 
$LANG['networking'][6]="Network port"; 
$LANG['networking'][13]="networking ports found"; 
$LANG['networking'][14]="IP"; 
$LANG['networking'][15]="MAC"; 
$LANG['networking'][17]="Bağlantı Bilgisi"; 
$LANG['networking'][19]="Ağ portu ekle"; 
$LANG['networking'][21]="Port number"; 
$LANG['networking'][25]="on"; 
$LANG['networking'][37]="networking port(s) found"; 
$LANG['networking'][44]="The port"; 
$LANG['networking'][46]="Birden fazla port ekle"; 
$LANG['networking'][47]="From"; 
$LANG['networking'][48]="To"; 
$LANG['networking'][51]="Bağlantı Noktası"; 
$LANG['networking'][55]="Vlan'ı ilişkilendir"; 
$LANG['networking'][56]="VLAN"; 
$LANG['networking'][57]="Listeden bir MAC adresi seçiniz yahut belirtiniz"; 
$LANG['networking'][58]="Dissociate a VLAN"; 
$LANG['networking'][59]="Gateway"; 
$LANG['networking'][60]="Mask"; 
$LANG['networking'][61]="Subnet"; 

$LANG['ocsconfig'][1]="OCSNG database user"; 
$LANG['ocsconfig'][2]="Host for the OCSNG database"; 
$LANG['ocsconfig'][3]="OCSNG user password"; 
$LANG['ocsconfig'][4]="Name of the OCSNG database"; 
$LANG['ocsconfig'][5]="Seçenekleri İçe Aktar"; 
$LANG['ocsconfig'][6]="Ignore in OCSNG import"; 
$LANG['ocsconfig'][7]="OCSNG database in UTF8"; 
$LANG['ocsconfig'][9]="Exclude the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][10]="Toplu aktarım"; 
$LANG['ocsconfig'][11]="Aktarılan olmadı."; 
$LANG['ocsconfig'][12]="Unit import"; 
$LANG['ocsconfig'][13]="Unit import: everything is imported 'as-is'"; 
$LANG['ocsconfig'][14]="Toplu aktarım: toplu yöetimdeki tüm nesneler herşeyiyle aktarılacaktır. (çift kayıtlar hariç)"; 
$LANG['ocsconfig'][15]="No import: the plugin will not import these elements"; 
$LANG['ocsconfig'][16]="Varsayılan durum"; 
$LANG['ocsconfig'][17]="Limit the import to the following tags (separator $, nothing for all)"; 
$LANG['ocsconfig'][18]="Öncelikle, OCSNG de çift kayıt olup olmadığını kontrol ediniz."; 
$LANG['ocsconfig'][19]="Unit import on serial number"; 
$LANG['ocsconfig'][27]="Genel bilgiler"; 
$LANG['ocsconfig'][36]="Modem"; 
$LANG['ocsconfig'][37]="Portlar"; 
$LANG['ocsconfig'][38]="Use the OCSNG software dictionary"; 
$LANG['ocsconfig'][39]="OCSNG TAG"; 
$LANG['ocsconfig'][40]="Number of items to synchronize via the automatic OCSNG action"; 
$LANG['ocsconfig'][41]="Registry"; 
$LANG['ocsconfig'][43]="OCSNG Administrative Information"; 
$LANG['ocsconfig'][48]="Behavior when disconnecting"; 
$LANG['ocsconfig'][49]="Trash"; 
$LANG['ocsconfig'][50]="Deletion"; 
$LANG['ocsconfig'][52]="Automatic connection of computers"; 
$LANG['ocsconfig'][53]="Enable the automatic link"; 
$LANG['ocsconfig'][54]="Existence criteria of a computer"; 
$LANG['ocsconfig'][55]="Find computers having the status"; 
$LANG['ocsconfig'][56]="Bos"; 
$LANG['ocsconfig'][57]="Esit"; 
$LANG['ocsconfig'][58]="The link automatically connects a GLPI computer with one in OCSNG.<br>This option is taken into account during manual link and by synchronization scripts."; 
$LANG['ocsconfig'][59]="Web address of the OCSNG console"; 

$LANG['ocsng'][0]="OCS Inventory NG"; 
$LANG['ocsng'][1]="Daha önceden aktarılmış bilgisayarları eşitle"; 
$LANG['ocsng'][2]="Yeni bilgisayarları aktar"; 
$LANG['ocsng'][3]="Clean links between GLPI and OCSNG"; 
$LANG['ocsng'][4]="Mevcut GLPI bilgisayarları ile yeni OCS bilgisayarlarını bağla"; 
$LANG['ocsng'][5]="Yeni bilgisayarları aktar"; 
$LANG['ocsng'][6]="Otomatik güncelleme"; 
$LANG['ocsng'][7]="OCSNG'den aktarıldı"; 
$LANG['ocsng'][8]="Aktarım başarılı"; 
$LANG['ocsng'][9]="No new computer to be imported"; 
$LANG['ocsng'][10]="Computers updated in OCSNG"; 
$LANG['ocsng'][11]="Bilgisayarları güncelle"; 
$LANG['ocsng'][12]="No new computer to be updated"; 
$LANG['ocsng'][13]="GLPI'a aktarılma tarihi"; 
$LANG['ocsng'][14]="Last OCSNG inventory date"; 
$LANG['ocsng'][15]="No field locked"; 
$LANG['ocsng'][16]="Locked Fields"; 
$LANG['ocsng'][18]="Connection to OCSNG database successful"; 
$LANG['ocsng'][19]="Valid OCSNG configuration and version"; 
$LANG['ocsng'][20]="Invalid OCSNG Version: RC3 is required"; 
$LANG['ocsng'][21]="Connection to the OCSNG database failed"; 
$LANG['ocsng'][22]="DİKKAT! Aktarılan veriler (konfigürasyonunuza bakınız) mevcut verilerinizin üzerine yazılacak."; 
$LANG['ocsng'][23]="Unable to import, GLPI computer is already related to an element of OCSNG"; 
$LANG['ocsng'][24]="Eşitlemeye zorla"; 
$LANG['ocsng'][26]="Choice of an OCSNG server"; 
$LANG['ocsng'][27]="No OCSNG server defined"; 
$LANG['ocsng'][29]="OCSNG server"; 
$LANG['ocsng'][30]="Locked monitor(s)"; 
$LANG['ocsng'][32]="Locked device(s)"; 
$LANG['ocsng'][34]="Locked printer(s)"; 
$LANG['ocsng'][36]="Destination entity"; 
$LANG['ocsng'][37]="Önizlemeyi aktif et"; 
$LANG['ocsng'][38]="Önizlemeyi iptal et"; 
$LANG['ocsng'][40]="Match the rule ?"; 
$LANG['ocsng'][41]="Elle aktarım modu"; 
$LANG['ocsng'][42]="Invalid OCSNG configuration (TRACE_DELETED must be active)"; 
$LANG['ocsng'][43]="Access denied on OCSNG database (Need write rights on hardware.CHECKSUM necessary)"; 
$LANG['ocsng'][44]="Access denied on OCSNG database (Delete rights in deleted_equiv table necessary)"; 
$LANG['ocsng'][45]="OCS ID"; 
$LANG['ocsng'][46]="Deleted in OCSNG"; 
$LANG['ocsng'][47]="Linked with an OCSNG computer"; 
$LANG['ocsng'][48]="The OCSNG ID of the computer changed"; 
$LANG['ocsng'][49]="Aracı"; 
$LANG['ocsng'][50]="Locked IP(s)"; 
$LANG['ocsng'][52]="Locked software(s)"; 
$LANG['ocsng'][54]="Software deleted by OCSNG synchronization"; 
$LANG['ocsng'][55]="Volume(s) locked(s)"; 
$LANG['ocsng'][57]="OCSNG Interface"; 

$LANG['pager'][1]="to"; 
$LANG['pager'][2]="from"; 
$LANG['pager'][3]="of"; 
$LANG['pager'][4]="Göster"; 
$LANG['pager'][5]="öğe"; 

$LANG['peripherals'][18]="Marka"; 
$LANG['peripherals'][31]="Genel Yönetim"; 
$LANG['peripherals'][32]="Unit management"; 
$LANG['peripherals'][33]="Yönetim Tipi"; 

$LANG['phones'][18]="Marka"; 
$LANG['phones'][36]="Güç Kaynağı"; 
$LANG['phones'][38]="Kulaklık"; 
$LANG['phones'][39]="Ahize"; 
$LANG['phones'][40]="Hat sayısı"; 

$LANG['planning'][0]="Bu zaman için planlanan teknik kişinin aynı saatte başka bir görevi var."; 
$LANG['planning'][1]="Error in entering dates. The starting date is later than the ending date"; 
$LANG['planning'][5]="Gün"; 
$LANG['planning'][6]="Hafta"; 
$LANG['planning'][8]="Tracking"; 
$LANG['planning'][9]="By"; 
$LANG['planning'][10]="Ical"; 
$LANG['planning'][11]="Webcal"; 
$LANG['planning'][12]="Download the planning in Ical format"; 
$LANG['planning'][13]="webcal:// Synchronization"; 
$LANG['planning'][14]="Ay"; 
$LANG['planning'][15]="Sizin Planınız"; 
$LANG['planning'][16]="Bilgilendirme"; 
$LANG['planning'][17]="To do"; 
$LANG['planning'][18]="Tamam"; 

$LANG['plugins'][0]="Eklenti Listesi"; 
$LANG['plugins'][2]="Kuruldu / Ayarlanmadı"; 
$LANG['plugins'][3]="Kuruldu / Aktif değil"; 
$LANG['plugins'][4]="Hata / temizlenemedi"; 
$LANG['plugins'][5]="Non-existent function(s)"; 
$LANG['plugins'][6]="To update"; 
$LANG['plugins'][7]="No plugin installed"; 
$LANG['plugins'][8]="See the catalog of plugins"; 
$LANG['plugins'][9]="Authors"; 
$LANG['plugins'][10]="Incompatible plugin with this version of GLPI"; 

$LANG['printers'][14]="Seri"; 
$LANG['printers'][15]="Paralel"; 
$LANG['printers'][18]="Port"; 
$LANG['printers'][27]="USB"; 
$LANG['printers'][28]="Ethernet"; 
$LANG['printers'][29]="Wifi"; 
$LANG['printers'][30]="Initial page counter"; 
$LANG['printers'][31]="Baskı sayfası"; 

$LANG['profiles'][0]="Global right"; 
$LANG['profiles'][1]="Entity Right"; 
$LANG['profiles'][2]="Profile's interface"; 
$LANG['profiles'][4]="Add a followup to tickets of associated group(s)"; 
$LANG['profiles'][5]="Çağrı aç"; 
$LANG['profiles'][6]="Add a followup to tickets (requester)"; 
$LANG['profiles'][7]="Tüm çağrıları göster"; 
$LANG['profiles'][8]="View all follow-ups and tasks (public and private)"; 
$LANG['profiles'][9]="Show public followups and tasks"; 
$LANG['profiles'][10]="Okuma"; 
$LANG['profiles'][11]="Yazma"; 
$LANG['profiles'][12]="Giriş Yapılamaz"; 
$LANG['profiles'][13]="Varsayılan Profil"; 
$LANG['profiles'][14]="Çağrı sil"; 
$LANG['profiles'][15]="Tüm çağrılara izlenebilirlik ekle"; 
$LANG['profiles'][16]="To be in charge of a ticket"; 
$LANG['profiles'][17]="Çağrı'yı devral"; 
$LANG['profiles'][18]="Çağrıyı Güncelle"; 
$LANG['profiles'][19]="Çağrı ata"; 
$LANG['profiles'][20]="Kişisel Planı Göster"; 
$LANG['profiles'][21]="View all plannings"; 
$LANG['profiles'][22]="Profil"; 
$LANG['profiles'][23]="Rezervasyon Yöneticisi"; 
$LANG['profiles'][24]="Parola Güncelle"; 
$LANG['profiles'][26]="Show tickets created by my groups"; 
$LANG['profiles'][27]="See hardware of my group(s)"; 
$LANG['profiles'][28]="Recursive"; 
$LANG['profiles'][29]="Dinamik"; 
$LANG['profiles'][30]="OCSNG bilgisini göster"; 
$LANG['profiles'][31]="OCSNG'yi elle eşitle"; 
$LANG['profiles'][32]="Atanmış çağrılara bak (kişisel ve üye olduğu gruplar)"; 
$LANG['profiles'][33]="No user founded"; 
$LANG['profiles'][34]="Başlık"; 
$LANG['profiles'][35]="Tüm takipleri güncelle"; 
$LANG['profiles'][36]="See schedule of people in my groups"; 
$LANG['profiles'][37]="Default entity"; 
$LANG['profiles'][38]="Visibility"; 
$LANG['profiles'][39]="Atamak"; 
$LANG['profiles'][40]="Güncelle"; 
$LANG['profiles'][41]="Oluşturma"; 
$LANG['profiles'][42]="İlişki"; 
$LANG['profiles'][43]="Kullanıcıları yetkilendirme ve senkronize etme metodu"; 
$LANG['profiles'][44]="Change the priority"; 
$LANG['profiles'][45]="Add a task to all tickets"; 
$LANG['profiles'][46]="Edit all tasks"; 
$LANG['profiles'][47]="Add users from an external source"; 
$LANG['profiles'][48]="Create a validation request"; 
$LANG['profiles'][49]="Validate a ticket"; 

$LANG['registry'][1]="Hive"; 
$LANG['registry'][2]="Yol"; 
$LANG['registry'][3]="Key/value"; 
$LANG['registry'][4]="Registry key(s) found"; 
$LANG['registry'][5]="No key found in registry"; 
$LANG['registry'][6]="OCSNG name"; 

$LANG['reminder'][0]="Kişisel notlar"; 
$LANG['reminder'][1]="Genel notlar"; 
$LANG['reminder'][6]="Yeni not"; 
$LANG['reminder'][9]="Metin"; 
$LANG['reminder'][12]="Add to schedule"; 
$LANG['reminder'][15]="Başlıksız"; 
$LANG['reminder'][16]="Genel Notlar"; 

$LANG['reports'][0]="Rapor Seçiniz"; 
$LANG['reports'][4]="Sözleşmeli donanımlar listesi"; 
$LANG['reports'][11]="Sözleşmeli donanım"; 
$LANG['reports'][12]="Donanım Tipi"; 
$LANG['reports'][13]="Tarih"; 
$LANG['reports'][15]="Raporu Göster"; 
$LANG['reports'][19]="Alternate username"; 
$LANG['reports'][26]="Varsayılan rapor"; 
$LANG['reports'][27]="Sözleşmeye göre"; 
$LANG['reports'][28]="Yıla göre"; 
$LANG['reports'][33]="Ağ raporu"; 
$LANG['reports'][36]="Bağlı aygıtlar"; 
$LANG['reports'][37]="Network outlets"; 
$LANG['reports'][38]="IP"; 
$LANG['reports'][39]="Lokasyona göre"; 
$LANG['reports'][41]="By hardware"; 
$LANG['reports'][42]="By network outlet"; 
$LANG['reports'][46]="hardware ports"; 
$LANG['reports'][47]="device ports"; 
$LANG['reports'][49]="Donanıma göre ağ raporu"; 
$LANG['reports'][51]="Network report by outlet"; 
$LANG['reports'][52]="switch"; 
$LANG['reports'][54]="Lokasyona göre ağ raporu"; 
$LANG['reports'][57]="Malzeme Listesi"; 
$LANG['reports'][58]="Equipment's report by year"; 
$LANG['reports'][60]="Kayıt tarihi"; 
$LANG['reports'][61]="Closing date"; 
$LANG['reports'][62]="Hardware Financial Information"; 
$LANG['reports'][63]="Diğer Finansal Bilgiler (Lisans, Kartuş, Sarf vs)"; 
$LANG['reports'][64]="Resolution date"; 

$LANG['reservation'][1]="Rezerv Edilebilir Öğeler"; 
$LANG['reservation'][2]="Device temporarily unavailable"; 
$LANG['reservation'][3]="Make unavailable"; 
$LANG['reservation'][5]="Make available"; 
$LANG['reservation'][6]="Prohibit reservations"; 
$LANG['reservation'][7]="Authorize reservations"; 
$LANG['reservation'][8]="Reserve"; 
$LANG['reservation'][9]="Reserve an item"; 
$LANG['reservation'][16]="To"; 
$LANG['reservation'][17]="From"; 
$LANG['reservation'][18]="Bu öğenin belirtilen zaman aralığı için rezervasyonu daha önce yapılmış."; 
$LANG['reservation'][20]="Back to planning"; 
$LANG['reservation'][21]="See planning"; 
$LANG['reservation'][22]="Modify the comment"; 
$LANG['reservation'][25]="All reservable hardware"; 
$LANG['reservation'][27]="Rehearsal"; 
$LANG['reservation'][28]="Haftaya göre"; 
$LANG['reservation'][29]="Güne göre"; 
$LANG['reservation'][30]="times"; 
$LANG['reservation'][31]="By"; 
$LANG['reservation'][35]="Gelecekteki ve işlemdeki rezervasyonlar"; 
$LANG['reservation'][36]="Geçmiş Rezervasyonlar"; 
$LANG['reservation'][37]="Rezervasyon Yok"; 
$LANG['reservation'][38]="Are you sure you want do return this non-reservable item ?"; 
$LANG['reservation'][39]="Bu işlem şu anda devam eden rezervasyonları iptal edecek."; 
$LANG['reservation'][40]="Material reservations expiring today"; 

$LANG['rulesengine'][0]="is"; 
$LANG['rulesengine'][1]="is not"; 
$LANG['rulesengine'][2]="içersin"; 
$LANG['rulesengine'][3]="içermiyor"; 
$LANG['rulesengine'][4]="starting with"; 
$LANG['rulesengine'][5]="finished by"; 
$LANG['rulesengine'][6]="Kriter"; 
$LANG['rulesengine'][7]="Hareketler"; 
$LANG['rulesengine'][8]="Kural yönetimi"; 
$LANG['rulesengine'][9]="Logical operator"; 
$LANG['rulesengine'][10]="Position"; 
$LANG['rulesengine'][11]="Hareket Tipi"; 
$LANG['rulesengine'][12]="Alanlar"; 
$LANG['rulesengine'][13]="Değer"; 
$LANG['rulesengine'][14]="Durum"; 
$LANG['rulesengine'][15]="Reason"; 
$LANG['rulesengine'][16]="Kriter"; 
$LANG['rulesengine'][17]="Kural"; 
$LANG['rulesengine'][18]="Rules for assigning a computer to an entity"; 
$LANG['rulesengine'][19]="Entity and rights assignment rules"; 
$LANG['rulesengine'][20]="Rules applied"; 
$LANG['rulesengine'][21]="Rules applicable in the sub-entities"; 
$LANG['rulesengine'][22]="Atama"; 
$LANG['rulesengine'][23]="Local rules"; 
$LANG['rulesengine'][24]="Kural Tipi"; 
$LANG['rulesengine'][25]="Computer's name"; 
$LANG['rulesengine'][26]="regular expression checks"; 
$LANG['rulesengine'][27]="regular expression does not match"; 
$LANG['rulesengine'][28]="Business rules for tickets"; 
$LANG['rulesengine'][29]="Kural listesi"; 
$LANG['rulesengine'][30]="Hareket"; 
$LANG['rulesengine'][33]="Açılırliste Sözlüğü"; 
$LANG['rulesengine'][35]="Yazılım Sözlüğü"; 
$LANG['rulesengine'][36]="Üretici Sözlüğü"; 
$LANG['rulesengine'][37]="Rules for assigning a category to software"; 
$LANG['rulesengine'][38]="Recalculate"; 
$LANG['rulesengine'][40]="Sınıf"; 
$LANG['rulesengine'][41]="Validation"; 
$LANG['rulesengine'][42]="Ve"; 
$LANG['rulesengine'][43]="Veya"; 
$LANG['rulesengine'][45]="Assign the value from regular expression"; 
$LANG['rulesengine'][46]="Assign: equipment by IP address"; 
$LANG['rulesengine'][47]="Assign: equipment by name + domain"; 
$LANG['rulesengine'][48]="Assign equipment"; 
$LANG['rulesengine'][49]="Assign: equipment by MAC address"; 
$LANG['rulesengine'][50]="Bilgisayar Model Sözlüğü"; 
$LANG['rulesengine'][51]="Monitör Model Sözlüğü"; 
$LANG['rulesengine'][52]="Telefon Model Sözlüğü"; 
$LANG['rulesengine'][53]="Çevre Birimleri Model Sözlüğü"; 
$LANG['rulesengine'][54]="Yazıcı Model Sözlüğü"; 
$LANG['rulesengine'][55]="Ağ Cihazları Model Sözlüğü"; 
$LANG['rulesengine'][56]="Model"; 
$LANG['rulesengine'][60]="Bilgisayar Tipleri Sözlüğü"; 
$LANG['rulesengine'][61]="Monitör Tipleri Sözlüğü"; 
$LANG['rulesengine'][62]="Telefon Tipleri Sözlüğü"; 
$LANG['rulesengine'][63]="Cevre Birimleri Tipleri Sözlüğü"; 
$LANG['rulesengine'][64]="Yazıcı Tipleri Sözlüğü"; 
$LANG['rulesengine'][65]="Ağ Cihaz Tipleri Sözlüğü"; 
$LANG['rulesengine'][66]="Tip"; 
$LANG['rulesengine'][67]="Operating systems dictionary"; 
$LANG['rulesengine'][68]="Yama Sözlüğü"; 
$LANG['rulesengine'][69]="İşletim Sistemi Versiyonları Sözlüğü"; 
$LANG['rulesengine'][70]="Rules for assigning a ticket created through a mail receiver"; 
$LANG['rulesengine'][76]="Rename based on dictionary"; 
$LANG['rulesengine'][77]="Sözlükler"; 
$LANG['rulesengine'][78]="Versiyon"; 
$LANG['rulesengine'][79]="Add the result from regular expression"; 
$LANG['rulesengine'][80]="Genel"; 
$LANG['rulesengine'][81]="Kural sonuçları"; 
$LANG['rulesengine'][82]="Result details"; 
$LANG['rulesengine'][83]="It is possible to affect the result of a regular expression using the string #0"; 
$LANG['rulesengine'][84]="Test rules engine"; 
$LANG['rulesengine'][85]="Result of the regular expression"; 
$LANG['rulesengine'][86]="Softwarecategory affected when software deleted by dictionary"; 
$LANG['rulesengine'][87]="Software deleted by GLPI dictionary"; 
$LANG['rulesengine'][90]="İşlem devam ediyor."; 
$LANG['rulesengine'][91]="İş bitti"; 
$LANG['rulesengine'][92]="Warning before running rename based on the dictionary"; 
$LANG['rulesengine'][93]="Warning! This operation can put software in the trash.<br>Sure to notify your users."; 
$LANG['rulesengine'][94]="FUSION"; 
$LANG['rulesengine'][95]="Üretici tercihi"; 
$LANG['rulesengine'][96]="Rename based on the manufacturer(s)dictionary<br> ( ----- = All)"; 
$LANG['rulesengine'][97]="No element to be tested"; 
$LANG['rulesengine'][100]="Cache bilgileri"; 
$LANG['rulesengine'][102]="Kural adı"; 
$LANG['rulesengine'][103]="Objects in cache"; 
$LANG['rulesengine'][104]="Gerçek değer"; 
$LANG['rulesengine'][105]="Değiştirilen değer"; 
$LANG['rulesengine'][106]="Değişmemiş"; 
$LANG['rulesengine'][107]="Pasif"; 
$LANG['rulesengine'][108]="Orjinal"; 
$LANG['rulesengine'][110]="Yetkilendirme"; 
$LANG['rulesengine'][111]="Entities assignment"; 
$LANG['rulesengine'][112]="Rights and entities assignment"; 
$LANG['rulesengine'][120]="The engine stops on the first checked rule."; 
$LANG['rulesengine'][121]="The engine treats all the rules."; 
$LANG['rulesengine'][122]="The engine passes the result of a rule to the following ones."; 
$LANG['rulesengine'][130]="Entity from LDAP"; 
$LANG['rulesengine'][131]="Entity from TAG"; 
$LANG['rulesengine'][132]="To be unaware of import"; 
$LANG['rulesengine'][133]="Entity from domain"; 
$LANG['rulesengine'][134]="Reject email (without email response)"; 
$LANG['rulesengine'][135]="Reject email (with email response)"; 
$LANG['rulesengine'][138]="LDAP criterias"; 
$LANG['rulesengine'][140]="Add a criterium"; 
$LANG['rulesengine'][142]="List of not imported emails"; 
$LANG['rulesengine'][144]="Entity based on user's profile"; 
$LANG['rulesengine'][145]="User with a single profile"; 
$LANG['rulesengine'][146]="User featuring the profile"; 
$LANG['rulesengine'][147]="User featuring a single profile"; 
$LANG['rulesengine'][148]="Mail domain is known"; 
$LANG['rulesengine'][150]="The rules linked with the entity have been disabled."; 

$LANG['search'][0]="Ara"; 
$LANG['search'][1]="for all"; 
$LANG['search'][2]="içersin"; 
$LANG['search'][4]="Sıralama"; 
$LANG['search'][8]="Başlangış tarihi"; 
$LANG['search'][9]="Bitiş tarihi"; 
$LANG['search'][10]="de"; 
$LANG['search'][11]="Görünende"; 
$LANG['search'][12]="Indicate an ended date"; 
$LANG['search'][15]="Öğe bulunamadı"; 
$LANG['search'][16]="En az"; 
$LANG['search'][17]="Arama kriteri ekle"; 
$LANG['search'][18]="Arama kriteri sil"; 
$LANG['search'][19]="Genel arama kriteri ekle"; 
$LANG['search'][20]="Genel arama kriteri sil"; 

$LANG['setup'][0]="Açılırliste"; 
$LANG['setup'][2]="Kullanıcı ekle"; 
$LANG['setup'][3]="LDAP directory link"; 
$LANG['setup'][4]="Bilgisayar Tipi"; 
$LANG['setup'][5]="İşletim Sistemi"; 
$LANG['setup'][6]="Personalization"; 
$LANG['setup'][9]="Ağ Arayüzü"; 
$LANG['setup'][10]="Display order of surnames firstnames"; 
$LANG['setup'][14]="Email"; 
$LANG['setup'][18]="Login"; 
$LANG['setup'][19]="Password"; 
$LANG['setup'][20]="Password confirmation"; 
$LANG['setup'][21]="Error : the two passwords are not identical"; 
$LANG['setup'][35]="MHz"; 
$LANG['setup'][39]="Followed private for default"; 
$LANG['setup'][40]="Private tasks by default"; 
$LANG['setup'][41]="Kullanacağınız Dil"; 
$LANG['setup'][42]="Ağ Tipi"; 
$LANG['setup'][43]="Yazıcı Tipi"; 
$LANG['setup'][44]="Monitör Tipi"; 
$LANG['setup'][45]="Durum tipi"; 
$LANG['setup'][46]="Default value"; 
$LANG['setup'][47]="Default chart format"; 
$LANG['setup'][48]="Default values"; 
$LANG['setup'][62]="Yapılandıracağınız sınıfı seçiniz"; 
$LANG['setup'][63]="Caution: you're about to remove a heading used for one or more items"; 
$LANG['setup'][64]="If you confirm the deletion the items using this heading used fields will be blanked"; 
$LANG['setup'][65]="You can also replace all the events of this heading by another:"; 
$LANG['setup'][67]="Harici yetkilendirme"; 
$LANG['setup'][69]="Aygıt tipi"; 
$LANG['setup'][70]="Genel ayar"; 
$LANG['setup'][71]="Aygıt Yazılımı"; 
$LANG['setup'][73]="Bağlantı Noktası"; 
$LANG['setup'][74]="You can't delete that place, because it has sub-places"; 
$LANG['setup'][75]="As child of"; 
$LANG['setup'][79]="Çağrı kategorileri"; 
$LANG['setup'][80]="Third party Type"; 
$LANG['setup'][81]="Döküman Başlıkları"; 
$LANG['setup'][82]="Contact Type"; 
$LANG['setup'][83]="Öğe durumu"; 
$LANG['setup'][84]="Kartuş/Toner Tipi"; 
$LANG['setup'][85]="Sözleşme Tipi"; 
$LANG['setup'][86]="Type of memory"; 
$LANG['setup'][87]="Knowledge base categories"; 
$LANG['setup'][88]="Ağ"; 
$LANG['setup'][89]="Domain"; 
$LANG['setup'][90]="VLAN'lar"; 
$LANG['setup'][91]="Bilgisayar Modeli"; 
$LANG['setup'][92]="Consumables Type"; 
$LANG['setup'][93]="Hard Disk Arayüzü"; 
$LANG['setup'][94]="Monitör Modeli"; 
$LANG['setup'][95]="Networking Models"; 
$LANG['setup'][96]="Yazıcı Modelleri"; 
$LANG['setup'][97]="Peripherals Models"; 
$LANG['setup'][98]="Tasks category"; 
$LANG['setup'][99]="Building number"; 
$LANG['setup'][100]="Room number"; 
$LANG['setup'][101]="Maximal number of automatic actions (run by CLI)"; 
$LANG['setup'][102]="Log Seviyesi"; 
$LANG['setup'][103]="1- Critical (login error only)"; 
$LANG['setup'][104]="2- Büyük (Kullanılmamış)"; 
$LANG['setup'][105]="3- Important (successful logins)"; 
$LANG['setup'][106]="4- Uyarılar (Ekleme, silme, izleme)"; 
$LANG['setup'][107]="5- Tamamı"; 
$LANG['setup'][109]="How long system logs are keep in database (in days, 0 for infinite)"; 
$LANG['setup'][110]="Show new tickets on the home page"; 
$LANG['setup'][111]="Maximum number of search results to display on a page"; 
$LANG['setup'][112]="Maximum number of characters for each items in dropdowns"; 
$LANG['setup'][113]="Varsayilan Dil"; 
$LANG['setup'][114]="Öncelik renkleri"; 
$LANG['setup'][115]="Default threshold for cartridge and consumable count"; 
$LANG['setup'][116]="Çağrıyı otomatik olarak görevdeki teknik kişiye ata"; 
$LANG['setup'][117]="SSS herkes tarafından görülebilsin"; 
$LANG['setup'][118]="Text on the login page"; 
$LANG['setup'][119]="Display"; 
$LANG['setup'][120]="Use dynamic display for dropdowns and text fields"; 
$LANG['setup'][121]="Character to force the full display of dropdowns (wildcard)"; 
$LANG['setup'][122]="Maximum number of items to display in the dropdowns when wildcard is not used"; 
$LANG['setup'][123]="Don't use dynamic display if the number of items is less than"; 
$LANG['setup'][124]="Automatically add users from an external authentication source"; 
$LANG['setup'][125]="... Harici bir kaynaktan"; 
$LANG['setup'][126]="Automatically add a user of an external source"; 
$LANG['setup'][127]="Autocompletion of text fields"; 
$LANG['setup'][128]="Tarih Formatı"; 
$LANG['setup'][129]="Show GLPI ID"; 
$LANG['setup'][130]="Number of days this action logs are stored"; 
$LANG['setup'][132]="Display the complete name in the tree dropdowns"; 
$LANG['setup'][133]="OCSNG'i aktif et."; 
$LANG['setup'][134]="OCSNG Modu"; 
$LANG['setup'][135]="Normal"; 
$LANG['setup'][136]="Çeviri"; 
$LANG['setup'][137]="Debug"; 
$LANG['setup'][138]="GLPI çalışma modu"; 
$LANG['setup'][139]="Genel"; 
$LANG['setup'][140]="Types"; 
$LANG['setup'][145]="Os"; 
$LANG['setup'][147]="Dynamic display"; 
$LANG['setup'][148]="Step for the hours"; 
$LANG['setup'][149]="Number of decimals in amounts"; 
$LANG['setup'][150]="Rakam Formatı"; 
$LANG['setup'][154]="Basedn"; 
$LANG['setup'][155]="rootdn (for non anonymous binds)"; 
$LANG['setup'][156]="Parola (anonymous olmayan bağlantılar için)"; 
$LANG['setup'][157]="PHP sürümünüzde LDAP eklentisi yüklenmemiş"; 
$LANG['setup'][158]="Impossible to use LDAP as external source of connection"; 
$LANG['setup'][159]="Bağlantı filtresi"; 
$LANG['setup'][162]="IMAP/POP konfigurasyonu"; 
$LANG['setup'][164]="IMAP/POP Host Name <br>(users email will be login@thishost)"; 
$LANG['setup'][165]="Your PHP parser was compiled without the IMAP functions"; 
$LANG['setup'][166]="Impossible to use IMAP/POP as external source of connection"; 
$LANG['setup'][167]="LDAP directory / GLPI links"; 
$LANG['setup'][168]="Bağlantı seçenekleri"; 
$LANG['setup'][169]="Mail folder (optional, often INBOX)"; 
$LANG['setup'][170]="Connection string"; 
$LANG['setup'][171]="Port (tercihli)"; 
$LANG['setup'][172]="Port (default=389)"; 
$LANG['setup'][174]="CAS Hostu"; 
$LANG['setup'][175]="Port"; 
$LANG['setup'][176]="Root directory (optional)"; 
$LANG['setup'][177]="CAS konfigurasyonu"; 
$LANG['setup'][178]="The CURL or DOMXML extension for your PHP parser isn't installed"; 
$LANG['setup'][179]="CAS harici bağlantı kaynağı olarak kullanılamıyor"; 
$LANG['setup'][180]="Use TLS"; 
$LANG['setup'][181]="'ldap_start_tls' parametresi bulunamadı"; 
$LANG['setup'][182]="Logout fallback URL"; 
$LANG['setup'][185]="Logs in files (SQL, email, automatic action...)"; 
$LANG['setup'][186]="Saat Dilimi"; 
$LANG['setup'][190]="x509 certificate"; 
$LANG['setup'][191]="email attribute for x509"; 
$LANG['setup'][192]="Enabled"; 
$LANG['setup'][193]="Field holding the login in the _SERVER array"; 
$LANG['setup'][194]="Additional informations retrieval from LDAP directory"; 
$LANG['setup'][195]="Keep status"; 
$LANG['setup'][196]="Clear status"; 
$LANG['setup'][197]="Bilgisayar durumunu kopyala"; 
$LANG['setup'][198]="Set status"; 
$LANG['setup'][199]="Remove the domain of login in form login@domain"; 
$LANG['setup'][200]="Infinite"; 
$LANG['setup'][201]="Alert and email followups configuration"; 
$LANG['setup'][202]="Enable Follow-up via email"; 
$LANG['setup'][203]="Yönetici Email'i"; 
$LANG['setup'][204]="İmza"; 
$LANG['setup'][205]="Yöneticiye mail gönderildi"; 
$LANG['setup'][206]="Yöneticiye mail gönderme başarısız"; 
$LANG['setup'][207]="Yönetici'ye cevap e-mail adresi (gerekiyorsa)"; 
$LANG['setup'][217]="The PHP mail function is unknown or isn't activated on your system"; 
$LANG['setup'][218]="SMTP kullanımı gereklidir"; 
$LANG['setup'][219]="Allow anonymous ticket creation (helpdesk.receiver)"; 
$LANG['setup'][221]="Beginning of fiscal year"; 
$LANG['setup'][223]="Limit of the schedules for planning"; 
$LANG['setup'][227]="URL of the application"; 
$LANG['setup'][228]="Login Field"; 
$LANG['setup'][229]="Send a test email to the administrator"; 
$LANG['setup'][231]="Use a SMTP server to send emails"; 
$LANG['setup'][232]="SMTP Host"; 
$LANG['setup'][234]="SMTP Login (optional)"; 
$LANG['setup'][235]="SMTP Password (optional)"; 
$LANG['setup'][236]="Former technician in charge of the ticket"; 
$LANG['setup'][237]="Yönetici"; 
$LANG['setup'][239]="Technician in charge of this ticket"; 
$LANG['setup'][240]="Uyarı seçenekleri"; 
$LANG['setup'][241]="Kişisel kriter tanımlı değil, tanımlansın mı?"; 
$LANG['setup'][242]="Alarm opsiyonları"; 
$LANG['setup'][243]="Sarf malzeme alarmı"; 
$LANG['setup'][244]="Kartuş/Toner Alarmı"; 
$LANG['setup'][245]="Reminders frequency"; 
$LANG['setup'][246]="Sözleşme alarmı"; 
$LANG['setup'][247]="Finansal bilgi alarmı"; 
$LANG['setup'][248]="Group in charge of the ticket"; 
$LANG['setup'][249]="Talep eden grup"; 
$LANG['setup'][250]="Display search results by default"; 
$LANG['setup'][252]="Varsayılan görünüm için öğeleri seçin"; 
$LANG['setup'][253]="Filter to search in groups"; 
$LANG['setup'][254]="Arama tipi"; 
$LANG['setup'][255]="Group attribute containing its users"; 
$LANG['setup'][256]="USER tanımı içinde"; 
$LANG['setup'][257]="GROUP tanımı içinde"; 
$LANG['setup'][258]="Kullancılar & Gruplar"; 
$LANG['setup'][259]="Gruplara ait"; 
$LANG['setup'][260]="User attribute containing its groups"; 
$LANG['setup'][261]="Group DN"; 
$LANG['setup'][262]="Use DN in the search"; 
$LANG['setup'][263]="Kullanıcılarda Arama"; 
$LANG['setup'][264]="Tarihi geçmiş lisans alarmı"; 
$LANG['setup'][271]="Monitör yönetimini kısıtla"; 
$LANG['setup'][272]="Aygıt yönetimini kısıtla"; 
$LANG['setup'][273]="Telefon yönetimini kısıtla"; 
$LANG['setup'][274]="elle eklemek için"; 
$LANG['setup'][275]="Yazıcı yönetimini kısıtla"; 
$LANG['setup'][280]="Automatically update of the elements related to the computers"; 
$LANG['setup'][281]="When connecting or updating"; 
$LANG['setup'][282]="When disconnecting"; 
$LANG['setup'][283]="Kopyala"; 
$LANG['setup'][284]="Temiz"; 
$LANG['setup'][285]="Do not copy"; 
$LANG['setup'][286]="Do not delete"; 
$LANG['setup'][300]="Yeni versiyon varsa kontrol et"; 
$LANG['setup'][301]="Yeni sürüm bulundu"; 
$LANG['setup'][302]="You will find it on the GLPI-PROJECT.org site"; 
$LANG['setup'][303]="En son sürüme sahipsiniz"; 
$LANG['setup'][304]="Bağlantı sağlanamadı. Eğer vekil sunucu kullanıyorsanız lütfen ayarlarını tam yapınız."; 
$LANG['setup'][305]="Her gün"; 
$LANG['setup'][306]="Güncellemeyi kontrol et"; 
$LANG['setup'][307]="Asla"; 
$LANG['setup'][308]="Her hafta"; 
$LANG['setup'][309]="Her Ay"; 
$LANG['setup'][310]="Impossible to connect to site."; 
$LANG['setup'][311]="Proxy Sunucuyla baglantı sağlanamadı"; 
$LANG['setup'][312]="No data available on the web site"; 
$LANG['setup'][313]="Be careful : there is no default value"; 
$LANG['setup'][350]="Link with items for the creation of tickets"; 
$LANG['setup'][351]="Tüm Öğeler"; 
$LANG['setup'][352]="Linkable items to a ticket"; 
$LANG['setup'][360]="Otomatik alanlar (* la işaretli)"; 
$LANG['setup'][400]="Proxy configuration"; 
$LANG['setup'][407]="Simplified interface help link"; 
$LANG['setup'][408]="Standard interface help link"; 
$LANG['setup'][409]="Default heading when adding a document to a ticket"; 
$LANG['setup'][503]="Telefon Modeli"; 
$LANG['setup'][504]="Telefon Tipi"; 
$LANG['setup'][505]="Telefon Güç Kaynağı Tipi"; 
$LANG['setup'][601]="LDAP değeri"; 
$LANG['setup'][602]="Connection to OCSNG database"; 
$LANG['setup'][603]="Kullanici Ekle"; 
$LANG['setup'][604]="Grup'a ilişkilendir"; 
$LANG['setup'][606]="Unable to add. The user already exists."; 
$LANG['setup'][607]="Profile ilişkilendir"; 
$LANG['setup'][608]="Software associable to a ticket by default"; 
$LANG['setup'][609]="Unable to add. The OCSNG server already exists."; 
$LANG['setup'][610]="Compulsory title of the ticket"; 
$LANG['setup'][611]="Compulsory ticket content"; 
$LANG['setup'][612]="Compulsory ticket category"; 
$LANG['setup'][613]="Add a user who have no accreditation from a LDAP directory"; 
$LANG['setup'][614]="Unable to update login. A user already exists."; 
$LANG['setup'][615]="Life cycle of tickets"; 
$LANG['setup'][616]="From \ To"; 
$LANG['setup'][620]="Link"; 
$LANG['setup'][621]="Search filter for entities"; 
$LANG['setup'][622]="Attribute representing entity"; 
$LANG['setup'][623]="Import entities from LDAP directory"; 
$LANG['setup'][650]="PHP"; 
$LANG['setup'][651]="SMTP"; 
$LANG['setup'][652]="SMTP+SSL"; 
$LANG['setup'][653]="SMTP+TLS"; 
$LANG['setup'][660]="Mail server"; 
$LANG['setup'][661]="Impossible to configure the notifications : please enable email monitoring"; 
$LANG['setup'][703]="Genel"; 
$LANG['setup'][704]="Uyarı"; 
$LANG['setup'][707]="Alerts on reservations"; 
$LANG['setup'][708]="Alerts on tickets which are not solved since"; 
$LANG['setup'][720]="System informations"; 
$LANG['setup'][721]="Information about system installation and configuration"; 
$LANG['setup'][722]="To copy/paste in your support request"; 
$LANG['setup'][731]="Value of the global configuration"; 
$LANG['setup'][732]="Domain of electronic mail service"; 
$LANG['setup'][800]="Mysql replicate"; 
$LANG['setup'][801]="Enable the MySQL replicate"; 
$LANG['setup'][802]="Veritabani"; 
$LANG['setup'][803]="Difference between master and slave"; 
$LANG['setup'][806]="Max delay between master and slave (minutes)"; 
$LANG['setup'][807]="The slave base is desynchronized. The difference is of:"; 
$LANG['setup'][808]="Slave database out of sync!"; 
$LANG['setup'][809]="MySQL replica: read only"; 
$LANG['setup'][810]="Desynchronization MySQL replication"; 

$LANG['software'][1]="Purchase version"; 
$LANG['software'][2]="Version in use"; 
$LANG['software'][3]="Not installed affected licenses"; 
$LANG['software'][4]="Unlimited"; 
$LANG['software'][5]="Versiyon"; 
$LANG['software'][6]="Publisher"; 
$LANG['software'][7]="Versiyon Ekle"; 
$LANG['software'][8]="Lisans Ekle"; 
$LANG['software'][11]="Lisanslar"; 
$LANG['software'][17]="Kurulmuş Yazılımlar"; 
$LANG['software'][19]="Yüklü Yazılımlar"; 
$LANG['software'][20]="Remaining"; 
$LANG['software'][28]="OEM"; 
$LANG['software'][29]="Güncelle"; 
$LANG['software'][30]="Lisans tipleri"; 
$LANG['software'][32]="Sonaerme"; 
$LANG['software'][44]="Yazılım Kur"; 
$LANG['software'][45]="Yazılımı kaldır"; 
$LANG['software'][46]="Associable to a ticket"; 
$LANG['software'][47]="Merging"; 
$LANG['software'][48]="Merge"; 
$LANG['software'][49]="Software deleted after merging"; 
$LANG['software'][50]="Bilgisayara tahsis edildi."; 
$LANG['software'][51]="The number must be 1 to be able to affect"; 

$LANG['softwarecategories'][2]="Uncategorized software"; 
$LANG['softwarecategories'][3]="Unfold the software without category"; 
$LANG['softwarecategories'][4]="Unfold the software belonging to a category"; 
$LANG['softwarecategories'][5]="Yazılım Sınıfı"; 

$LANG['state'][0]="Durum"; 
$LANG['state'][6]="Öğe Tipi"; 
$LANG['state'][7]="Öğe bulunamadı"; 
$LANG['state'][11]="Özet"; 

$LANG['stats'][0]="İstatistik Seçiniz"; 
$LANG['stats'][1]="Genel"; 
$LANG['stats'][2]="No item to display"; 
$LANG['stats'][3]="Parçaya Göre"; 
$LANG['stats'][5]="Number of opened tickets"; 
$LANG['stats'][6]="Ortalama çözüm süresi"; 
$LANG['stats'][7]="Show graphics"; 
$LANG['stats'][11]="Çözülmüş Çağrı Sayısı"; 
$LANG['stats'][13]="Çağrı Sayısı"; 
$LANG['stats'][15]="Ortalama çözüm süresi"; 
$LANG['stats'][16]="Teknisyen ismi"; 
$LANG['stats'][20]="Kullanıcı Adı"; 
$LANG['stats'][23]="İstatistik yok"; 
$LANG['stats'][25]="Ortalama İşlem Süresi"; 
$LANG['stats'][27]="Toplam İşlem Süresi"; 
$LANG['stats'][30]="Ortalama cevaplama süresi"; 
$LANG['stats'][31]="Gün"; 
$LANG['stats'][33]="Dak"; 
$LANG['stats'][34]="Sn"; 
$LANG['stats'][35]="Çağrı"; 
$LANG['stats'][44]="Tedarikçi Adı"; 
$LANG['stats'][45]="Donanıma göre"; 
$LANG['stats'][47]="Çağrıya göre"; 
$LANG['stats'][48]="(atanmış)"; 
$LANG['stats'][49]="Takip edilenler"; 

$LANG['title'][5]="Kütüphane"; 
$LANG['title'][6]="Ağ"; 
$LANG['title'][9]="Öğe Durumu"; 
$LANG['title'][10]="Çağrı izleme"; 
$LANG['title'][13]="Kullanıcı Bilgisi"; 
$LANG['title'][14]="Harici yetkilendirme kaynakları"; 
$LANG['title'][24]="Destek"; 
$LANG['title'][26]="Temel"; 
$LANG['title'][27]="Bağlantılar"; 
$LANG['title'][28]="Çağrılar"; 
$LANG['title'][30]="Parçalar"; 
$LANG['title'][33]="Harici bağlantılar"; 
$LANG['title'][34]="Bağlantılar"; 
$LANG['title'][37]="Notlar"; 
$LANG['title'][38]="Geçmiş"; 
$LANG['title'][40]="Genel ve özel notlar"; 
$LANG['title'][42]="Genel değişiklik"; 
$LANG['title'][43]="Tescil"; 

$LANG['tracking'][1]="Aygıtlarım"; 
$LANG['tracking'][2]="Veya tam arama"; 
$LANG['tracking'][3]="Hatalı tarih. Güncelleme iptal edildi."; 
$LANG['tracking'][4]="There is no urgency in your ticket, please correct."; 
$LANG['tracking'][8]="No description for your ticket, please retry."; 
$LANG['tracking'][9]="Default for tickets"; 
$LANG['tracking'][10]="Default for mail recipients"; 
$LANG['tracking'][24]="Çağrı dökümantesi"; 
$LANG['tracking'][29]="Numara"; 
$LANG['tracking'][30]="Yeni"; 
$LANG['tracking'][31]="İşlemde (Atanmış)"; 
$LANG['tracking'][32]="İşlemde (Planlanmış)"; 
$LANG['tracking'][34]="Doğrudan"; 
$LANG['tracking'][35]="Yazıldı"; 
$LANG['tracking'][37]="Donanım envanterden silinsede çağrıları silme"; 
$LANG['tracking'][38]="Email Gönderilen:"; 
$LANG['tracking'][39]="Visible in the simplified interface"; 

$LANG['transfer'][1]="Aktarma"; 
$LANG['transfer'][3]="Eğer kullanılmıyorsa"; 
$LANG['transfer'][4]="To empty the list of elements to be transferred"; 
$LANG['transfer'][5]="You can continue to add elements to be transferred or execute the transfer now"; 
$LANG['transfer'][6]="Öğeleri aktarmadan önce yedeklemenizi öneririz."; 
$LANG['transfer'][7]="Aktarılacak öğeler"; 
$LANG['transfer'][8]="Aktarma tipi"; 

$LANG['update'][88]="The version of the database is not compatible with the version of the installed files. An update is necessary."; 
$LANG['update'][89]="You are trying to use GLPI with files from an earlier version to the version of the database. Please install the files corresponding to the version of your database."; 
$LANG['update'][90]="Veritabanı güncellemesinde hata"; 
$LANG['update'][91]="Dikkat!"; 
$LANG['update'][92]="Güncellenecek GLPI veritabanı ismi :"; 
$LANG['update'][93]="Veritabanı bağlantısı sağlandı"; 
$LANG['update'][94]="Güncelleme başarılı, veritabanınız güncel."; 
$LANG['update'][95]="Veritabanı bağlantısı hatalı, config_db.php dosyasındaki bağlantı parametrelerini kontrol ediniz."; 
$LANG['update'][96]="Artık tüm Administrator'lar 'super-admin' yetkisine sahipler. Yeni kullanıcı tipi de eklendi."; 
$LANG['update'][105]="Impossible to accomplish an update this way!!"; 
$LANG['update'][106]="GLPI'a geri dön"; 
$LANG['update'][107]="Şimdi veritabanını güncellemelisiniz."; 
$LANG['update'][130]="Lokasyonları Güncelleme"; 
$LANG['update'][131]="The new structure is hierarchical"; 
$LANG['update'][132]="Provide a delimiter in order to automate the new hierarchy generation."; 
$LANG['update'][133]="You can also specify a root location which will include all the generated locations."; 
$LANG['update'][134]="Delimiter"; 
$LANG['update'][135]="Root location"; 
$LANG['update'][136]="Bu yenilenmiş düzendir. Eğer uygun ise onaylayabilirsiniz."; 
$LANG['update'][137]="Yeni hiyerarşi"; 
$LANG['update'][138]="Aktif lokasyonlar"; 
$LANG['update'][139]="Optimizing tables"; 
$LANG['update'][140]="Creating indexes"; 
$LANG['update'][141]="Change of the database layout"; 
$LANG['update'][142]="Data migration"; 

$LANG['users'][1]="Ünvan"; 
$LANG['users'][2]="Sınıf"; 

$LANG['validation'][0]="Approval"; 
$LANG['validation'][1]="Send a Approval request"; 
$LANG['validation'][2]="Status"; 
$LANG['validation'][3]="Request date"; 
$LANG['validation'][4]="Approval date"; 
$LANG['validation'][5]="Request comment"; 
$LANG['validation'][6]="Approval comment"; 
$LANG['validation'][7]="Approval(s) for the ticket"; 
$LANG['validation'][9]="Waiting for approval"; 
$LANG['validation'][10]="Refused"; 
$LANG['validation'][11]="Granted"; 
$LANG['validation'][12]="Not subject to approval"; 
$LANG['validation'][13]="Approval request send to"; 
$LANG['validation'][15]="Ticket waiting for your Approval"; 
$LANG['validation'][16]="Optional when approved"; 
$LANG['validation'][18]="Approval requester"; 
$LANG['validation'][19]="Approval granted"; 
$LANG['validation'][20]="Approval denied"; 
$LANG['validation'][21]="Approver"; 
$LANG['validation'][23]="The selected user has no valid emailaddress. The request has been created, without email confirmation."; 
$LANG['validation'][26]="Approval request"; 
$LANG['validation'][27]="An approval request has been submitted"; 
$LANG['validation'][28]="Status of the Approval request"; 
$LANG['validation'][29]="If approval is denied, specify a reason"; 
$LANG['validation'][30]="Cancel the approval request to"; 
$LANG['validation'][31]="Update the Approval request to"; 
$LANG['validation'][32]="An answer to a Approval request was produced"; 
$LANG['validation'][33]="Tickets awaiting approval"; 
?>